@@ -288,7 +288,7 @@ itemconfig_t *LoadItemConfig(char *filename)
 	PC_SetBaseFolder(BOTFILESBASEFOLDER);
 	source = LoadSourceFile( path );
 	if( !source ) {
-		botimport.Print( PRT_ERROR, "counldn't load %s\n", path );
+		botimport.Print( PRT_ERROR, "couldn't load %s\n", path );
 		return NULL;
 	} //end if
 	//initialize item config
