@@ -224,7 +224,7 @@ weaponconfig_t *LoadWeaponConfig(char *filename)
 	source = LoadSourceFile(path);
 	if (!source)
 	{
-		botimport.Print(PRT_ERROR, "counldn't load %s\n", path);
+		botimport.Print(PRT_ERROR, "couldn't load %s\n", path);
 		return NULL;
 	} //end if
 	//initialize weapon config
