@@ -471,6 +471,33 @@ void CL_JoystickEvent( int axis, int value, int time ) {
 	cl.joystickAxis[axis] = value;
 }
 
+/*
+=================
+CL_UpdateMouse
+
+Added in OPM
+Update mouse position with absolute position (relative to the window)
+when the UI catcher is active.
+=================
+*/
+void CL_UpdateMouse() {
+    if (!(Key_GetCatcher() & KEYCATCH_UI)) {
+        return;
+    }
+
+    if (IN_IsCursorActive()) {
+        // If it's grabbed, don't use absolute position
+        return;
+    }
+
+    if (com_unfocused->integer) {
+        // Ignore updates when unfocused
+        return;
+    }
+
+    IN_GetMousePosition(&cl.mousex, &cl.mousey);
+}
+
 /*
 =================
 CL_JoystickMove
@@ -866,8 +893,8 @@ qboolean CL_ReadyToSendPacket( void ) {
 	}
 
 	// check for exceeding cl_maxpackets
-	if ( cl_maxpackets->integer < 15 ) {
-		Cvar_Set( "cl_maxpackets", "15" );
+	if ( cl_maxpackets->integer < 30 ) {
+		Cvar_Set( "cl_maxpackets", "30" );
 	} else if ( cl_maxpackets->integer > 125 ) {
 		Cvar_Set( "cl_maxpackets", "125" );
 	}
