@@ -256,10 +256,9 @@ movement on the server game.
 #define PMF_VIEW_DUCK_RUN   (1 << 9)
 #define PMF_VIEW_JUMP_START (1 << 10)
 #define PMF_LEVELEXIT       (1 << 11)
-#define PMF_NO_GRAVITY      (1 << 12)
-#define PMF_NO_HUD          (1 << 13)
-#define PMF_TURRET          (1 << 14)
-#define PMF_NO_LEAN         (1 << 15)
+#define PMF_TURRET          (1 << 12)
+#define PMF_NO_WEAPONBAR    (1 << 14)
+#define PMF_NO_HUD          (1 << 15)
 
     // moveposflags
     enum moveposflags_e {
@@ -651,8 +650,9 @@ movement on the server game.
 #define MASK_LOOK        (CONTENTS_SOLID | CONTENTS_LAVA | CONTENTS_SLIME | CONTENTS_FENCE)
 #define MASK_CAMERASOLID (CONTENTS_SOLID | CONTENTS_PLAYERCLIP | CONTENTS_BODY | MASK_WATER)
 #define MASK_BEAM        (CONTENTS_SOLID | CONTENTS_TRIGGER | CONTENTS_PLAYERCLIP | CONTENTS_BODY | CONTENTS_FENCE)
-#define MASK_LADDER \
-    (CONTENTS_SOLID | CONTENTS_LADDER | CONTENTS_TRIGGER | CONTENTS_PLAYERCLIP | CONTENTS_BODY | CONTENTS_FENCE | CONTENTS_UNKNOWN2 | CONTENTS_NOBOTCLIP | CONTENTS_BBOX)
+#define MASK_LADDER                                                                                             \
+    (CONTENTS_SOLID | CONTENTS_LADDER | CONTENTS_TRIGGER | CONTENTS_PLAYERCLIP | CONTENTS_BODY | CONTENTS_FENCE \
+     | CONTENTS_UNKNOWN2 | CONTENTS_NOBOTCLIP | CONTENTS_BBOX)
 #define MASK_AUTOCALCLIFE (CONTENTS_SOLID | CONTENTS_TRIGGER | CONTENTS_FENCE)
 #define MASK_EXPLOSION    (CONTENTS_SOLID | CONTENTS_TRIGGER | CONTENTS_WEAPONCLIP)
 #define MASK_SOUND        (CONTENTS_SOLID | CONTENTS_TRANSLUCENT)
@@ -770,8 +770,8 @@ movement on the server game.
         CGM_HUDDRAW_ALPHA,
         CGM_HUDDRAW_STRING,
         CGM_HUDDRAW_FONT,
-        CGM_NOTIFY_KILL,
         CGM_NOTIFY_HIT,
+        CGM_NOTIFY_KILL,
         CGM_VOICE_CHAT,
         CGM_FENCEPOST,
     };
@@ -812,8 +812,8 @@ movement on the server game.
         CGM6_HUDDRAW_ALPHA,
         CGM6_HUDDRAW_STRING,
         CGM6_HUDDRAW_FONT,
-        CGM6_NOTIFY_KILL,
         CGM6_NOTIFY_HIT,
+        CGM6_NOTIFY_KILL,
         CGM6_VOICE_CHAT,
     };
 
