@@ -457,7 +457,6 @@ void Door::SetCloseEndSound(str sound)
 }
 
 void Door::SetMessageSound(str sound)
-
 {
     sound_message = sound;
     if (sound_message.length() > 1) {
@@ -730,7 +729,6 @@ void Door::Open(Event *ev)
 }
 
 void Door::DoorUse(Event *ev)
-
 {
     Entity  *other;
     qboolean respond;
@@ -848,10 +846,11 @@ void Door::DoorBlocked(Event *ev)
         if (state == STATE_OPENING || state == STATE_OPEN) {
             spawnflags &= ~DOOR_START_OPEN;
 
+            const bool bWasOpening = (previous_state == STATE_CLOSING);
             const bool bIsMoving = EventPending(EV_MoveDone);
             ProcessEvent(EV_Door_Close);
 
-            if (bIsMoving) {
+            if (bIsMoving && !bWasOpening) {
                 // Added in OPM
                 //  Reopen to the other side so sentients can still pass.
                 //  This avoid entities like players trying to prevent the door
@@ -1454,7 +1453,6 @@ CLASS_DECLARATION(Door, SlidingDoor, "func_door") {
 };
 
 void SlidingDoor::SetMoveDir(Event *ev)
-
 {
     float t;
     float angle;
@@ -1473,13 +1471,11 @@ void SlidingDoor::DoOpen(Event *ev)
 }
 
 void SlidingDoor::DoClose(Event *ev)
-
 {
     MoveTo(pos1, angles, speed * totalmove, EV_Door_CloseEnd);
 }
 
 void SlidingDoor::SetLip(Event *ev)
-
 {
     lip = ev->GetFloat(1);
     CancelEventsOfType(EV_SlidingDoor_Setup);
@@ -1487,7 +1483,6 @@ void SlidingDoor::SetLip(Event *ev)
 }
 
 void SlidingDoor::SetSpeed(Event *ev)
-
 {
     basespeed = ev->GetFloat(1);
     CancelEventsOfType(EV_SlidingDoor_Setup);
@@ -1495,7 +1490,6 @@ void SlidingDoor::SetSpeed(Event *ev)
 }
 
 void SlidingDoor::Setup(Event *ev)
-
 {
     totalmove = fabs(movedir * size) - lip;
     pos1      = origin;
@@ -1601,7 +1595,6 @@ CLASS_DECLARATION(Door, ScriptDoor, "script_door") {
 };
 
 void ScriptDoor::SetMoveDir(Event *ev)
-
 {
     float t;
     float angle;
@@ -1662,7 +1655,6 @@ void ScriptDoor::DoClose(Event *ev)
 }
 
 void ScriptDoor::SetInitThread(Event *ev)
-
 {
     initlabel.SetThread(ev->GetValue(1));
 }
