@@ -757,6 +757,7 @@ void G_ClientUserinfoChanged(gentity_t *ent, const char *u)
     char      *s;
     gclient_t *client;
     int        clientnum;
+    char       oldname[MAX_NAME_LENGTH];
 
     if (!ent) {
         return;
@@ -772,6 +773,7 @@ void G_ClientUserinfoChanged(gentity_t *ent, const char *u)
 
     clientnum = ent - g_entities;
 
+    Q_strncpyz(oldname, client->pers.netname, sizeof(oldname));
     if (gi.SanitizeName(s, client->pers.netname, sizeof(client->pers.netname))) {
         gi.Printf("WARNING: had to sanitize the name for client %i\n", clientnum);
     }
@@ -815,6 +817,9 @@ void G_ClientUserinfoChanged(gentity_t *ent, const char *u)
         ent->entity->ProcessEvent(ev);
     }
 
+    Q_strncpyz(client->pers.ip, Info_ValueForKey(u, "ip"), sizeof(client->pers.ip));
+    client->pers.port = atoi(Info_ValueForKey(u, "port"));
+
     Q_strncpyz(client->pers.userinfo, u, sizeof(client->pers.userinfo));
 }
 
@@ -827,6 +832,7 @@ void G_BotConnect(int clientNum, qboolean firstTime, const char *userinfo)
 
     ent->client   = game.clients + clientNum;
     ent->s.number = clientNum;
+    ent->r.svFlags |= SVF_BOT;
 
     client = ent->client;
 
@@ -877,8 +883,6 @@ const char *G_ClientConnect(int clientNum, qboolean firstTime, qboolean differen
     gentity_t *ent;
     char       userinfo[MAX_INFO_STRING];
 
-    gi.DPrintf("TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT\n");
-
     // Added in OPM
     G_BotShift(clientNum);
 
@@ -886,6 +890,7 @@ const char *G_ClientConnect(int clientNum, qboolean firstTime, qboolean differen
 
     gi.GetUserinfo(clientNum, userinfo, sizeof(userinfo));
 
+#if 0
     // IP filtering
     // https://zerowing.idsoftware.com/bugzilla/show_bug.cgi?id=500
     // recommanding PB based IP / GUID banning, the builtin system is pretty limited
@@ -893,15 +898,16 @@ const char *G_ClientConnect(int clientNum, qboolean firstTime, qboolean differen
     ip   = Info_ValueForKey(userinfo, "ip");
     port = Info_ValueForKey(userinfo, "port");
 
-    // FIXME: what is fucking wrong with G_FilterPacket...
     // NOTE: IP banning is directly handled by the server
-    //if ( G_FilterPacket( value ) ) {
-    //	return "Banned IP";
-    //}
+    if ( G_FilterPacket( value ) ) {
+    	return "Banned IP";
+    }
+#endif
 
     // we don't check password for bots and local client
     // NOTE: local client <-> "ip" "localhost"
     //   this means this client is not running in our current process
+    ip = Info_ValueForKey(userinfo, "ip");
     if ((strcmp(ip, "localhost") != 0)) {
         // check for a password
         value = Info_ValueForKey(userinfo, "password");
@@ -935,9 +941,6 @@ const char *G_ClientConnect(int clientNum, qboolean firstTime, qboolean differen
         }
     }
 
-    Q_strncpyz(client->pers.ip, ip, sizeof(client->pers.ip));
-    client->pers.port = atoi(port);
-
     G_ClientUserinfoChanged(ent, userinfo);
 
 #if 0
@@ -953,9 +956,7 @@ const char *G_ClientConnect(int clientNum, qboolean firstTime, qboolean differen
 
     // don't do the "xxx connected" messages if they were caried over from previous level
     if (firstTime && g_gametype->integer != GT_SINGLE_PLAYER) {
-        if (dedicated->integer) {
-            gi.Printf("%s is preparing for deployment\n", client->pers.netname);
-        }
+        G_PrintfClient(ent, "is preparing for deployment\n");
 
         G_PrintToAllClients(va("%s is preparing for deployment\n", client->pers.netname), 2);
     }
@@ -973,6 +974,8 @@ and on transition between teams, but doesn't happen on respawns
 */
 void G_ClientBegin(gentity_t *ent, usercmd_t *cmd)
 {
+    Player *player = NULL;
+
     try {
         assert(ent->s.number < game.maxclients);
         assert(ent->client != NULL);
@@ -984,23 +987,34 @@ void G_ClientBegin(gentity_t *ent, usercmd_t *cmd)
             // state when the game is saved, so we need to compensate
             // with deltaangles
             ent->entity->SetDeltaAngles();
+
+            if (ent->entity->IsSubclassOfPlayer() && g_gametype->integer != GT_SINGLE_PLAYER) {
+                player = static_cast<Player *>(ent->entity);
+
+                // Added in OPM
+                //  When a client reuses an entity, make the player instance aware about it
+                if (player) {
+                    player->ResetClient();
+                }
+            }
         } else {
             // a spawn point will completely reinitialize the entity
             level.spawn_entnum = ent->s.number;
 
-            Player *player = new Player;
+            player = new Player;
         }
 
+        // Fixed in OPM
+        //  Initialize the enter time even when there is an intermission.
+        //  This is so in the scoreboard it shows up properly
+        ent->client->pers.enterTime = level.svsFloatTime;
+
         if (level.intermissiontime && ent->entity) {
             G_MoveClientToIntermission(ent->entity);
         } else {
-            ent->client->pers.enterTime = level.svsFloatTime;
-
             if (g_gametype->integer != GT_SINGLE_PLAYER) {
                 // send effect if in a multiplayer game
-                if (dedicated->integer) {
-                    gi.Printf("%s has entered the battle\n", ent->client->pers.netname);
-                }
+                G_PrintfClient(ent, "has entered the battle\n");
 
                 G_PrintToAllClients(va("%s has entered the battle\n", ent->client->pers.netname), 2);
             }
@@ -1061,6 +1075,8 @@ void G_ClientDisconnect(gentity_t *ent)
             return;
         }
 
+        G_PrintfClient(ent, "has left the battle\n");
+
         G_PrintToAllClients(va("%s has left the battle\n", ent->client->pers.netname), 2);
 
         assert(ent->entity->IsSubclassOfPlayer());
@@ -1135,3 +1151,36 @@ void G_ClientDisconnect(gentity_t *ent)
 	}
 #endif
 }
+
+/*
+===========
+G_PrintfClient
+
+Logs message with client context.
+For bots it falls back to regular print.
+============
+*/
+void G_PrintfClient(gentity_t *ent, const char *fmt, ...)
+{
+    va_list argptr;
+    char    msg[MAXPRINTMSG];
+
+    if (!dedicated->integer) {
+        return;
+    }
+
+    if (!ent->client) {
+        return;
+    }
+
+    va_start(argptr, fmt);
+    Q_vsnprintf(msg, sizeof(msg), fmt, argptr);
+    va_end(argptr);
+
+    if (ent->r.svFlags & SVF_BOT) {
+        gi.Printf("%s %s", ent->client->pers.netname, msg);
+        return;
+    }
+
+    gi.PrintfClient(ent - g_entities, "%s", msg);
+}
