@@ -248,6 +248,8 @@ typedef struct gameImport_s {
     void (*cvar_set)(const char *varName, const char *varValue);
     cvar_t *(*cvar_set2)(const char *varName, const char *varValue, qboolean force);
     cvar_t *(*NextCvar)(cvar_t *var);
+    void (*Cvar_CheckRange)(cvar_t* var, float min, float max, qboolean integral);
+
     int (*Argc)();
     char *(*Argv)(int arg);
     char *(*Args)();
@@ -257,6 +259,7 @@ typedef struct gameImport_s {
     int (*FS_WriteFile)(const char *qpath, const void *buffer, int size);
     fileHandle_t (*FS_FOpenFileWrite)(const char *fileName);
     fileHandle_t (*FS_FOpenFileAppend)(const char *fileName);
+    long (*FS_FOpenFile)(const char* qpath, fileHandle_t *file, qboolean uniqueFILE, qboolean quiet);
     const char *(*FS_PrepFileWrite)(const char *fileName);
     size_t (*FS_Write)(const void *buffer, size_t size, fileHandle_t fileHandle);
     size_t (*FS_Read)(void *buffer, size_t len, fileHandle_t fileHandle);
@@ -484,6 +487,11 @@ typedef struct gameImport_s {
     // Added in OPM
     //
 
+    /**
+     * Print a message related to a client
+     */
+    void (*PrintfClient)(int clientNum, const char *fmt, ...);
+
     int (*pvssoundindex)(const char* name, int streamed);
 
     cvar_t *fsDebug;
