@@ -1,6 +1,6 @@
 /*
 ===========================================================================
-Copyright (C) 2023 the OpenMoHAA team
+Copyright (C) 2025 the OpenMoHAA team
 
 This file is part of OpenMoHAA source code.
 
@@ -452,10 +452,10 @@ trace_t G_Trace(
 }
 
 void G_TraceEntities(
-    Vector             & start,
-    Vector             & mins,
-    Vector             & maxs,
-    Vector             & end,
+    Vector&              start,
+    Vector&              mins,
+    Vector&              maxs,
+    Vector&              end,
     Container<Entity *> *victimlist,
     int                  contentmask,
     qboolean             bIncludeTriggers
@@ -1321,9 +1321,9 @@ void G_ArchiveEdict(Archiver& arc, gentity_t *edict)
         arc.ArchiveString(&tempStr);
 
         if (tempStr.length()) {
-            qboolean streamed = tempStr[tempStr.length() - 1] != '0';
+            qboolean streamed             = tempStr[tempStr.length() - 1] != '0';
             tempStr[tempStr.length() - 1] = 0;
-            edict->s.loopSound = gi.soundindex(tempStr.c_str(), streamed);
+            edict->s.loopSound            = gi.soundindex(tempStr.c_str(), streamed);
         } else {
             edict->s.loopSound = 0;
         }
@@ -1768,24 +1768,7 @@ int G_AIEventTypeFromString(const char *pszType)
 
 float G_AIEventRadius(int iType)
 {
-    static float fRadius[] = {
-        0,
-        2048,
-        384,
-        4096,
-        1024,
-        1024,
-        1536,
-        1536,
-        1500,
-        2250,
-        512,
-        384,
-        32768,
-        0,
-        0,
-        0
-    };
+    static float fRadius[] = {0, 2048, 384, 4096, 1024, 1024, 1536, 1536, 1500, 2250, 512, 384, 32768, 0, 0, 0};
 
     if (iType >= AI_EVENT_MAX) {
         Com_Printf("G_AIEventRadius: invalid event type\n");
@@ -1838,7 +1821,7 @@ void G_BroadcastAIEvent(Entity *originator, Vector origin, int iType, float radi
             continue;
         }
 
-        act = static_cast<Actor*>(ent);
+        act = static_cast<Actor *>(ent);
         if (act->IgnoreSound(iType)) {
             continue;
         }
@@ -2161,19 +2144,36 @@ int G_NumClients(void)
 
 void G_PrintToAllClients(const char *pszString, int iType)
 {
+    gentity_t *ent;
+    int        i;
+
     if (g_protocol >= protocol_e::PROTOCOL_MOHTA_MIN) {
-        if (iType == 0) {
-            gi.SendServerCommand(-1, "print \"" HUD_MESSAGE_YELLOW "%s\"", pszString);
-        } else if (iType == 1) {
-            gi.SendServerCommand(-1, "print \"" HUD_MESSAGE_WHITE "%s\"", pszString);
-        } else if (iType == 2) {
-            gi.SendServerCommand(-1, "print \"" HUD_MESSAGE_CHAT_WHITE "%s\"", pszString);
+        for (i = 0; i < game.maxclients; i++) {
+            ent = &g_entities[i];
+            if (!ent->inuse || !ent->entity) {
+                continue;
+            }
+
+            if (iType == 0) {
+                gi.SendServerCommand(i, "print \"" HUD_MESSAGE_YELLOW "%s\"", pszString);
+            } else if (iType == 1) {
+                gi.SendServerCommand(i, "print \"" HUD_MESSAGE_WHITE "%s\"", pszString);
+            } else if (iType == 2) {
+                gi.SendServerCommand(i, "print \"" HUD_MESSAGE_CHAT_WHITE "%s\"", pszString);
+            }
         }
     } else {
-        if (iType == 0) {
-            gi.SendServerCommand(-1, "print \"" HUD_MESSAGE_YELLOW "%s\"", pszString);
-        } else {
-            gi.SendServerCommand(-1, "print \"" HUD_MESSAGE_WHITE "%s\"", pszString);
+        for (i = 0; i < game.maxclients; i++) {
+            ent = &g_entities[i];
+            if (!ent->inuse || !ent->entity) {
+                continue;
+            }
+
+            if (iType == 0) {
+                gi.SendServerCommand(i, "print \"" HUD_MESSAGE_YELLOW "%s\"", pszString);
+            } else {
+                gi.SendServerCommand(i, "print \"" HUD_MESSAGE_WHITE "%s\"", pszString);
+            }
         }
     }
 }
@@ -2453,6 +2453,14 @@ gentity_t *G_GetGEntity(int ent_num)
     return ent;
 }
 
-unsigned int G_GetWeaponCommand(unsigned int buttons) {
-    return GetWeaponCommand(buttons, g_protocol >= PROTOCOL_MOHTA_MIN ? WEAPON_COMMAND_MAX_VER17 : WEAPON_COMMAND_MAX_VER6);
+unsigned int G_GetWeaponCommandMask()
+{
+    return GetWeaponCommandMask(g_protocol >= PROTOCOL_MOHTA_MIN ? WEAPON_COMMAND_MAX_VER17 : WEAPON_COMMAND_MAX_VER6);
+}
+
+unsigned int G_GetWeaponCommand(unsigned int buttons)
+{
+    return GetWeaponCommand(
+        buttons, g_protocol >= PROTOCOL_MOHTA_MIN ? WEAPON_COMMAND_MAX_VER17 : WEAPON_COMMAND_MAX_VER6
+    );
 }
