@@ -1,6 +1,6 @@
 /*
 ===========================================================================
-Copyright (C) 2024 the OpenMoHAA team
+Copyright (C) 2025 the OpenMoHAA team
 
 This file is part of OpenMoHAA source code.
 
@@ -686,10 +686,17 @@ void GameScript::ArchiveCodePos(Archiver& arc, unsigned char **codePos)
 
 void GameScript::Close(void)
 {
+    // Free up catch blocks
     for (int i = m_CatchBlocks.NumObjects(); i > 0; i--) {
         delete m_CatchBlocks.ObjectAt(i);
     }
 
+    // Added in OPM
+    //  Free up allocated state scripts
+    for (int i = m_StateScripts.NumObjects(); i > 0; i--) {
+        delete m_StateScripts.ObjectAt(i);
+    }
+
     m_CatchBlocks.FreeObjectList();
 
     if (m_ProgToSource) {
@@ -814,7 +821,11 @@ StateScript *GameScript::CreateCatchStateScript(unsigned char *try_begin_code_po
 
 StateScript *GameScript::CreateSwitchStateScript(void)
 {
-    return new StateScript;
+    StateScript *stateScript = new StateScript;
+
+    m_StateScripts.AddObject(stateScript);
+
+    return stateScript;
 }
 
 StateScript *GameScript::GetCatchStateScript(unsigned char *in, unsigned char *& out)
@@ -866,7 +877,7 @@ ScriptThreadLabel::ScriptThreadLabel()
     m_Label  = STRING_EMPTY;
 }
 
-ScriptThread *ScriptThreadLabel::Create(Listener *listener)
+ScriptThread *ScriptThreadLabel::Create(Listener *listener) const
 {
     ScriptClass  *scriptClass;
     ScriptThread *thread;
@@ -896,7 +907,7 @@ ScriptThread *ScriptThreadLabel::Create(Listener *listener)
     return thread;
 }
 
-void ScriptThreadLabel::Execute(Listener *listener)
+void ScriptThreadLabel::Execute(Listener *listener) const
 {
     if (!m_Script) {
         return;
@@ -909,12 +920,7 @@ void ScriptThreadLabel::Execute(Listener *listener)
     }
 }
 
-void ScriptThreadLabel::Execute(Listener *listener, Event& ev)
-{
-    Execute(listener, &ev);
-}
-
-void ScriptThreadLabel::Execute(Listener *listener, Event *ev)
+void ScriptThreadLabel::Execute(Listener *listener, Event& ev) const
 {
     if (!m_Script) {
         return;
@@ -927,7 +933,14 @@ void ScriptThreadLabel::Execute(Listener *listener, Event *ev)
     }
 }
 
-void ScriptThreadLabel::Execute(Listener *pSelf, const SafePtr<Listener>& listener, const SafePtr<Listener>& param)
+void ScriptThreadLabel::Execute(Listener *listener, Event *ev) const
+{
+    Execute(listener, *ev);
+}
+
+void ScriptThreadLabel::Execute(
+    Listener *pSelf, const SafePtr<Listener>& listener, const SafePtr<Listener>& param
+) const
 {
     if (!m_Script) {
         return;
@@ -1214,7 +1227,7 @@ bool ScriptThreadLabel::TrySetScript(const_str label)
     return true;
 }
 
-void ScriptThreadLabel::GetScriptValue(ScriptVariable *var)
+void ScriptThreadLabel::GetScriptValue(ScriptVariable *var) const
 {
     if (!m_Script) {
         var->Clear();
@@ -1228,12 +1241,12 @@ void ScriptThreadLabel::GetScriptValue(ScriptVariable *var)
     var->setConstArrayValue(var_array, 2);
 }
 
-bool ScriptThreadLabel::IsSet(void)
+bool ScriptThreadLabel::IsSet(void) const
 {
     return m_Script != NULL;
 }
 
-bool ScriptThreadLabel::IsFile(const_str filename)
+bool ScriptThreadLabel::IsFile(const_str filename) const
 {
     return m_Script && m_Script->ConstFilename() == filename && m_Label == STRING_EMPTY;
 }
