@@ -35,6 +35,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "Entities.h"
 #include "health.h"
 
+#include "navigation_recast_load.h"
+
 #include "scriptmaster.h"
 #include "scriptthread.h"
 #include "scriptvariable.h"
@@ -855,6 +857,8 @@ void Level::CleanUp(qboolean samemap, qboolean resetConfigStrings)
     // clear active current bots
     G_ResetBots();
 
+    navigationMap.CleanUp(samemap);
+
     assert(active_edicts.next);
     assert(active_edicts.next->prev == &active_edicts);
     assert(active_edicts.prev);
@@ -1502,6 +1506,12 @@ void Level::ServerSpawned(void)
         Director.Unpause();
 
         Unregister(STRING_SPAWN);
+
+        if (!g_navigation_legacy->integer) {
+            // Added in OPM
+            //  Recast navigation
+            navigationMap.LoadWorldMap(m_mapfile);
+        }
     } else {
         Director.LoadMenus();
     }
@@ -1511,9 +1521,9 @@ void Level::ServerSpawned(void)
 
 void Level::SetMap(const char *themapname)
 {
-    char *spawnpos;
-    int   i;
-    str   text;
+    const char *spawnpos;
+    int         i;
+    str         text;
 
     Init();
 
@@ -1522,8 +1532,8 @@ void Level::SetMap(const char *themapname)
     // set a specific spawnpoint if the map was started with a $
     spawnpos = strchr((char *)themapname, '$');
     if (spawnpos) {
-        mapname    = (const char *)(spawnpos - themapname);
-        spawnpoint = mapname;
+        mapname    = str(themapname, 0, spawnpos - themapname);
+        spawnpoint = spawnpos + 1;
     } else {
         mapname    = themapname;
         spawnpoint = "";
@@ -1588,6 +1598,30 @@ void Level::Precache(void)
 
     LoadAllScripts("global", ".scr");
     InitVoteOptions();
+
+    // Added in OPM
+    //  Cache all player models in multi-player
+    //  This avoids using precache scripts
+    if (g_gametype->integer != GT_SINGLE_PLAYER) {
+        char **fileList;
+        int    numFiles;
+        int    i;
+
+        fileList = gi.FS_ListFiles("models/player", ".tik", qfalse, &numFiles);
+
+        for (i = 0; i < numFiles; i++) {
+            const char *filename = fileList[i];
+            const size_t filelen = strlen(filename);
+
+            if (!Q_stricmpn(filename, "allied_", 7) || !Q_stricmpn(filename, "american_", 9)
+                || !Q_stricmpn(filename, "german_", 7) || !Q_stricmpn(filename, "IT_", 3)
+                || !Q_stricmpn(filename, "SC_", 3)) {
+                CacheResource(va("models/player/%s", filename));
+            }
+        }
+
+        gi.FS_FreeFileList(fileList);
+    }
 }
 
 /*
@@ -1730,6 +1764,10 @@ void Level::FreeEdict(gentity_t *ed)
 {
     gclient_t *client;
 
+    // clear the model so it decreases the user count
+    // and free memory if the model is not used anywhere
+    gi.clearmodel(ed);
+
     // unlink from world
     gi.unlinkentity(ed);
 
@@ -1916,6 +1954,8 @@ void Level::CheckVote(void)
                 level.m_voteNo++;
             }
         }
+
+        numVoters++;
     }
 
     level.m_numVoters = numVoters;
