@@ -1001,7 +1001,7 @@ PathNode *PathSearch::FindCornerNodeForWall(
 
 PathNode *PathSearch::FindCornerNodeForExactPath(Entity *pSelf, Sentient *enemy, float fMaxPath)
 {
-    PathNode *pPathNode[4096];
+    PathNode *pPathNode[MAX_PATHNODES];
     PathNode *pParentNode;
     size_t    i, iDepth;
     Vector    vEnd;
@@ -1554,7 +1554,7 @@ void DrawNode(int iNodeCount)
     Vector    aStart;
     Vector    aEnd;
     PathNode *node;
-    PathNode *nodelist[4096];
+    PathNode *nodelist[MAX_PATHNODES];
     Vector    end;
     Vector    start;
     Vector    p;
@@ -1562,8 +1562,8 @@ void DrawNode(int iNodeCount)
 
     playerorigin = g_entities[0].client->ps.origin;
 
-    if (iNodeCount > 4096) {
-        iNodeCount = 4096;
+    if (iNodeCount > MAX_PATHNODES) {
+        iNodeCount = MAX_PATHNODES;
     }
 
     if (ai_showallnode->integer) {
@@ -2500,7 +2500,10 @@ PathNode *PathSearch::FindNearestSniperNode(Entity*pEnt, Vector& vPos, Entity *p
 
 PathNode *PathSearch::GetSpawnNode(ClassDef *cls)
 {
-    if (m_bNodesloaded) {
+    if (m_bNodesloaded
+        // Fixed in OPM
+        && m_LoadIndex < nodecount
+        ) {
         return pathnodes[m_LoadIndex++];
     } else {
         // Otherwise create a new node
