@@ -20,6 +20,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 ===========================================================================
 */
 // playerbot.cpp: Multiplayer bot system.
+//
+// FIXME: Refactor code and use OOP-based state system
 
 #include "g_local.h"
 #include "actor.h"
@@ -29,6 +31,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "scriptexception.h"
 #include "vehicleturret.h"
 #include "weaputils.h"
+#include "windows.h"
 #include "g_bot.h"
 
 // We assume that we have limited access to the server-side
@@ -65,10 +68,13 @@ BotController::BotController()
     m_botEyes.ofs[1]    = 0;
     m_botEyes.ofs[2]    = DEFAULT_VIEWHEIGHT;
 
-    m_iCuriousTime  = 0;
-    m_iAttackTime   = 0;
-    m_iConfirmTime  = 0;
-    m_iEnemyEyesTag = -1;
+    m_iCuriousTime        = 0;
+    m_iAttackTime         = 0;
+    m_iEnemyEyesTag       = -1;
+    m_iContinuousFireTime = 0;
+    m_iLastSeenTime       = 0;
+    m_iLastUnseenTime     = 0;
+    m_iLastBurstTime      = 0;
 
     m_iNextTauntTime = 0;
 
@@ -76,6 +82,16 @@ BotController::BotController()
     m_RunLabel.TrySetScript("global/bot_run.scr");
 }
 
+BotController::~BotController()
+{
+    if (controlledEnt) {
+        controlledEnt->delegate_gotKill.Remove(delegateHandle_gotKill);
+        controlledEnt->delegate_killed.Remove(delegateHandle_killed);
+        controlledEnt->delegate_stufftext.Remove(delegateHandle_stufftext);
+        controlledEnt->delegate_spawned.Remove(delegateHandle_spawned);
+    }
+}
+
 BotMovement& BotController::GetMovement()
 {
     return movement;
@@ -174,34 +190,83 @@ void BotController::CheckUse(void)
     Vector  end;
     trace_t trace;
 
+    if (controlledEnt->GetLadder()) {
+        return;
+    }
+
     controlledEnt->angles.AngleVectorsLeft(&dir);
 
     start = controlledEnt->origin + Vector(0, 0, controlledEnt->viewheight);
-    end   = controlledEnt->origin + Vector(0, 0, controlledEnt->viewheight) + dir * 32;
+    end   = controlledEnt->origin + Vector(0, 0, controlledEnt->viewheight) + dir * 64;
 
-    trace = G_Trace(start, vec_zero, vec_zero, end, controlledEnt, MASK_USABLE, false, "BotController::CheckUse");
+    trace = G_Trace(
+        start, vec_zero, vec_zero, end, controlledEnt, MASK_USABLE | MASK_LADDER, false, "BotController::CheckUse"
+    );
 
-    // It may be a door
-    if ((trace.allsolid || trace.startsolid || trace.fraction != 1.0f) && trace.ent) {
-        if (trace.ent->entity->IsSubclassOfDoor()) {
-            Door *door = static_cast<Door *>(trace.ent->entity);
-            if (door->isOpen()) {
-                m_botCmd.buttons &= ~BUTTON_USE;
-                return;
-            }
-        }
-
-        //
-        // Toggle the use button
-        //
-        m_botCmd.buttons ^= BUTTON_USE;
-    } else {
+    if (!trace.ent || trace.ent->entity == world) {
         m_botCmd.buttons &= ~BUTTON_USE;
+        return;
     }
+
+    if (trace.ent->entity->IsSubclassOfDoor()) {
+        Door *door = static_cast<Door *>(trace.ent->entity);
+        if (door->isOpen()) {
+            // Don't use an open door
+            m_botCmd.buttons &= ~BUTTON_USE;
+            return;
+        }
+    } else if (!trace.ent->entity->isSubclassOf(FuncLadder)) {
+        m_botCmd.buttons &= ~BUTTON_USE;
+        return;
+    }
+
+    //
+    // Toggle the use button
+    //
+    m_botCmd.buttons ^= BUTTON_USE;
+
+#if 0
+    Vector  forward;
+    Vector  start, end;
+
+    AngleVectors(controlledEnt->GetViewAngles(), forward, NULL, NULL);
+
+    start = (controlledEnt->m_vViewPos - forward * 12.0f);
+    end   = (controlledEnt->m_vViewPos + forward * 128.0f);
+
+    trace = G_Trace(start, vec_zero, vec_zero, end, controlledEnt, MASK_LADDER, qfalse, "checkladder");
+    if (trace.ent->entity && trace.ent->entity->isSubclassOf(FuncLadder)) {
+        return;
+    }
+
+    m_botCmd.buttons ^= BUTTON_USE;
+#endif
 }
 
-void BotController::CheckValidWeapon() {
-    Weapon* weapon = controlledEnt->GetActiveWeapon(WEAPON_MAIN);
+bool BotController::CheckWindows(void)
+{
+    trace_t trace;
+    Vector  start, end;
+    Vector  dir;
+
+    controlledEnt->angles.AngleVectorsLeft(&dir);
+    start = controlledEnt->origin + Vector(0, 0, controlledEnt->viewheight);
+    end   = controlledEnt->origin + Vector(0, 0, controlledEnt->viewheight) + dir * 64;
+
+    trace = G_Trace(start, vec_zero, vec_zero, end, controlledEnt, MASK_PLAYERSOLID, false, "BotController::CheckUse");
+
+    if (trace.fraction != 1 && trace.ent) {
+        if (trace.ent->entity->isSubclassOf(WindowObject)) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+void BotController::CheckValidWeapon()
+{
+    Weapon *weapon = controlledEnt->GetActiveWeapon(WEAPON_MAIN);
     if (!weapon) {
         // If holstered, use the best weapon available
         UseWeaponWithAmmo();
@@ -279,14 +344,23 @@ void BotController::AimAtAimNode(void)
         return;
     }
 
-    goal = movement.GetCurrentGoal();
-    if (goal != controlledEnt->origin) {
-        rotation.AimAt(goal);
-    }
+    //goal = movement.GetCurrentGoal();
+    //if (goal != controlledEnt->origin) {
+    //    rotation.AimAt(goal);
+    //}
 
-    Vector targetAngles = rotation.GetTargetAngles();
-    targetAngles.x      = 0;
-    rotation.SetTargetAngles(targetAngles);
+    if (controlledEnt->GetLadder()) {
+        Vector vAngles = movement.GetCurrentPathDirection().toAngles();
+        vAngles.x      = Q_clamp_float(vAngles.x, -80, 80);
+
+        rotation.SetTargetAngles(vAngles);
+        return;
+    } else {
+        Vector targetAngles;
+        targetAngles   = movement.GetCurrentPathDirection().toAngles();
+        targetAngles.x = 0;
+        rotation.SetTargetAngles(targetAngles);
+    }
 }
 
 /*
@@ -298,7 +372,14 @@ Make the bot reload if necessary
 */
 void BotController::CheckReload(void)
 {
-    Weapon *weap = controlledEnt->GetActiveWeapon(WEAPON_MAIN);
+    Weapon *weap;
+
+    if (level.inttime < m_iLastFireTime + 2000) {
+        // Don't reload while attacking
+        return;
+    }
+
+    weap = controlledEnt->GetActiveWeapon(WEAPON_MAIN);
 
     if (weap && weap->CheckReload(FIRE_PRIMARY)) {
         SendCommand("reload");
@@ -316,6 +397,15 @@ void BotController::NoticeEvent(Vector vPos, int iType, Entity *pEnt, float fDis
 {
     Sentient *pSentOwner;
     float     fRangeFactor;
+    Vector    delta1, delta2;
+
+    if (m_iCuriousTime) {
+        delta1 = vPos - controlledEnt->origin;
+        delta2 = m_vNewCuriousPos - controlledEnt->origin;
+        if (delta1.lengthSquared() < delta2.lengthSquared()) {
+            return;
+        }
+    }
 
     fRangeFactor = 1.0 - (fDistanceSquared / fRadiusSquared);
 
@@ -388,7 +478,6 @@ Clear the bot's enemy
 void BotController::ClearEnemy(void)
 {
     m_iAttackTime   = 0;
-    m_iConfirmTime  = 0;
     m_pEnemy        = NULL;
     m_iEnemyEyesTag = -1;
     m_vOldEnemyPos  = vec_zero;
@@ -508,8 +597,15 @@ bool BotController::CheckCondition_Idle(void)
 
 void BotController::State_Idle(void)
 {
+    if (CheckWindows()) {
+        m_botCmd.buttons ^= BUTTON_ATTACKLEFT;
+        m_iLastFireTime = level.inttime;
+    } else {
+        m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
+        CheckReload();
+    }
+
     AimAtAimNode();
-    CheckReload();
 
     if (!movement.MoveToBestAttractivePoint() && !movement.IsMoving()) {
         if (m_vLastDeathPos != vec_zero) {
@@ -520,9 +616,11 @@ void BotController::State_Idle(void)
             }
         } else {
             Vector randomDir(G_CRandom(16), G_CRandom(16), G_CRandom(16));
-            Vector preferredDir = Vector(controlledEnt->orientation[0]) * (rand() % 5 ? 1024 : -1024);
-            float  radius       = 512 + G_Random(2048);
+            Vector preferredDir;
+            float  radius = 512 + G_Random(2048);
 
+            preferredDir += Vector(controlledEnt->orientation[0]) * (rand() % 5 ? 1024 : -1024);
+            preferredDir += Vector(controlledEnt->orientation[2]) * (rand() % 5 ? 1024 : -1024);
             movement.AvoidPath(controlledEnt->origin + randomDir, radius, preferredDir);
         }
     }
@@ -562,6 +660,13 @@ bool BotController::CheckCondition_Curious(void)
 
 void BotController::State_Curious(void)
 {
+    if (CheckWindows()) {
+        m_botCmd.buttons ^= BUTTON_ATTACKLEFT;
+        m_iLastFireTime = level.inttime;
+    } else {
+        m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
+    }
+
     AimAtAimNode();
 
     if (!movement.MoveToBestAttractivePoint(3) && (!movement.IsMoving() || m_vLastCuriousPos != m_vNewCuriousPos)) {
@@ -671,19 +776,14 @@ bool BotController::CheckCondition_Attack(void)
             }
 
             if (!m_pEnemy) {
-                // Slight reaction time
-                m_iConfirmTime = level.inttime + (200 + G_Random(200));
-                m_iAttackTime = 0;
+                m_iLastUnseenTime = level.inttime;
             }
 
             m_pEnemy        = sent;
             m_vLastEnemyPos = m_pEnemy->origin;
-            if (level.inttime < m_iConfirmTime) {
-                return false;
-            }
         }
 
-        if (m_pEnemy && level.inttime >= m_iConfirmTime) {
+        if (m_pEnemy) {
             m_iAttackTime = level.inttime + 1000;
             return true;
         }
@@ -711,11 +811,13 @@ void BotController::State_Attack(void)
 {
     bool    bMelee              = false;
     bool    bCanSee             = false;
+    bool    bCanAttack          = false;
     float   fMinDistance        = 128;
     float   fMinDistanceSquared = fMinDistance * fMinDistance;
     float   fEnemyDistanceSquared;
     Weapon *pWeap   = controlledEnt->GetActiveWeapon(WEAPON_MAIN);
     bool    bNoMove = false;
+    bool    bFiring = false;
 
     if (!m_pEnemy || !IsValidEnemy(m_pEnemy)) {
         // Ignore dead enemies
@@ -728,97 +830,149 @@ void BotController::State_Attack(void)
 
     bCanSee =
         controlledEnt->CanSee(m_pEnemy, 20, Q_min(world->m_fAIVisionDistance, world->farplane_distance * 0.828), false);
+
     if (bCanSee) {
         if (!pWeap) {
             return;
         }
 
-        float fPrimaryBulletRange          = pWeap->GetBulletRange(FIRE_PRIMARY) / 1.25f;
-        float fPrimaryBulletRangeSquared   = fPrimaryBulletRange * fPrimaryBulletRange;
-        float fSecondaryBulletRange        = pWeap->GetBulletRange(FIRE_SECONDARY);
-        float fSecondaryBulletRangeSquared = fSecondaryBulletRange * fSecondaryBulletRange;
-        float fSpreadFactor                = pWeap->GetSpreadFactor(FIRE_PRIMARY);
-
-        //
-        // check the fire movement speed if the weapon has a max fire movement
-        //
-        if (pWeap->GetMaxFireMovement() < 1 && pWeap->HasAmmoInClip(FIRE_PRIMARY)) {
-            float length;
-
-            length = controlledEnt->velocity.length();
-            if ((length / sv_runspeed->value) > (pWeap->GetMaxFireMovementMult())) {
-                bNoMove = true;
-                movement.ClearMove();
+        bCanAttack = true;
+        if (m_iLastUnseenTime) {
+            const float reactionTime = Q_min(1000 * Q_min(1, fDistanceSquared / Square(2048)), 1000);
+            if (level.inttime <= m_iLastUnseenTime + 200 + G_Random(reactionTime)) {
+                bCanAttack = false;
+            } else {
+                m_iLastUnseenTime = 0;
             }
         }
 
-        fMinDistance = fPrimaryBulletRange;
+        if (bCanAttack) {
+            const int fireDelay                    = pWeap->FireDelay(FIRE_PRIMARY) * 1000;
+            float     fPrimaryBulletRange          = pWeap->GetBulletRange(FIRE_PRIMARY) / 1.25f;
+            float     fPrimaryBulletRangeSquared   = fPrimaryBulletRange * fPrimaryBulletRange;
+            float     fSecondaryBulletRange        = pWeap->GetBulletRange(FIRE_SECONDARY);
+            float     fSecondaryBulletRangeSquared = fSecondaryBulletRange * fSecondaryBulletRange;
+            float     fSpreadFactor                = pWeap->GetSpreadFactor(FIRE_PRIMARY);
 
-        if (fMinDistance > 256) {
-            fMinDistance = 256;
-        }
+            const int maxContinousFireTime = fireDelay + 500 + G_Random(1500);
+            const int maxBurstTime         = fireDelay + 100 + G_Random(500);
 
-        fMinDistanceSquared = fMinDistance * fMinDistance;
+            //
+            // check the fire movement speed if the weapon has a max fire movement
+            //
+            if (pWeap->GetMaxFireMovement() < 1 && pWeap->HasAmmoInClip(FIRE_PRIMARY)) {
+                float length;
 
-        if (controlledEnt->client->ps.stats[STAT_AMMO] > 0 || controlledEnt->client->ps.stats[STAT_CLIPAMMO] > 0) {
-            if (fDistanceSquared <= fPrimaryBulletRangeSquared) {
-                if (pWeap->IsSemiAuto()) {
-                    if (controlledEnt->client->ps.iViewModelAnim == VM_ANIM_IDLE
-                        || controlledEnt->client->ps.iViewModelAnim >= VM_ANIM_IDLE_0
-                               && controlledEnt->client->ps.iViewModelAnim <= VM_ANIM_IDLE_2) {
-                        if (fSpreadFactor < 0.25) {
-                            m_botCmd.buttons ^= BUTTON_ATTACKLEFT;
-                            if (pWeap->GetZoom()) {
-                                if (!controlledEnt->IsZoomed()) {
-                                    m_botCmd.buttons |= BUTTON_ATTACKRIGHT;
-                                } else {
-                                    m_botCmd.buttons &= ~BUTTON_ATTACKRIGHT;
-                                }
-                            }
-                        } else {
-                            bNoMove = true;
-                            movement.ClearMove();
-                        }
-                    } else {
-                        m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
-                        controlledEnt->ZoomOff();
-                    }
-                } else {
-                    m_botCmd.buttons |= BUTTON_ATTACKLEFT;
+                length = controlledEnt->velocity.length();
+                if ((length / sv_runspeed->value) > (pWeap->GetMaxFireMovementMult())) {
+                    bNoMove = true;
+                    movement.ClearMove();
                 }
-            } else {
+            }
+
+            fMinDistance = fPrimaryBulletRange;
+
+            if (fMinDistance > 256) {
+                fMinDistance = 256;
+            }
+
+            fMinDistanceSquared = fMinDistance * fMinDistance;
+
+            if (controlledEnt->client->ps.stats[STAT_AMMO] <= 0
+                && controlledEnt->client->ps.stats[STAT_CLIPAMMO] <= 0) {
+                m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
+                controlledEnt->ZoomOff();
+            } else if (fDistanceSquared > fPrimaryBulletRangeSquared) {
                 m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
                 controlledEnt->ZoomOff();
-            }
-        } else {
-            m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
-            controlledEnt->ZoomOff();
-        }
-
-        if (pWeap->GetFireType(FIRE_SECONDARY) == FT_MELEE) {
-            if (controlledEnt->client->ps.stats[STAT_AMMO] <= 0 && controlledEnt->client->ps.stats[STAT_CLIPAMMO] <= 0) {
-                bMelee = true;
-            } else if (fDistanceSquared <= fSecondaryBulletRangeSquared) {
-                bMelee = true;
-            }
-        }
-
-        if (bMelee) {
-            m_botCmd.buttons &= ~BUTTON_ATTACKLEFT;
-
-            if (fDistanceSquared <= fSecondaryBulletRangeSquared) {
-                m_botCmd.buttons ^= BUTTON_ATTACKRIGHT;
             } else {
-                m_botCmd.buttons &= ~BUTTON_ATTACKRIGHT;
-            }
-        }
+                //
+                // Attacking
+                //
 
-        m_iAttackTime        = level.inttime + 1000;
-        m_iAttackStopAimTime = level.inttime + 3000;
-        m_vLastEnemyPos      = m_pEnemy->centroid;
+                if (pWeap->IsSemiAuto()) {
+                    if (controlledEnt->client->ps.iViewModelAnim != VM_ANIM_IDLE
+                        && (controlledEnt->client->ps.iViewModelAnim < VM_ANIM_IDLE_0
+                            || controlledEnt->client->ps.iViewModelAnim > VM_ANIM_IDLE_2)) {
+                        m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
+                        controlledEnt->ZoomOff();
+                    } else if (fSpreadFactor < 0.25) {
+                        bFiring = true;
+                        m_botCmd.buttons ^= BUTTON_ATTACKLEFT;
+                        if (pWeap->GetZoom()) {
+                            if (!controlledEnt->IsZoomed()) {
+                                m_botCmd.buttons |= BUTTON_ATTACKRIGHT;
+                            } else {
+                                m_botCmd.buttons &= ~BUTTON_ATTACKRIGHT;
+                            }
+                        }
+                    } else {
+                        bNoMove = true;
+                        movement.ClearMove();
+                    }
+                } else {
+                    bFiring = true;
+                    m_botCmd.buttons |= BUTTON_ATTACKLEFT;
+                }
+            }
+
+            //
+            // Burst
+            //
+
+            if (m_iLastBurstTime) {
+                if (level.inttime > m_iLastBurstTime + maxBurstTime) {
+                    m_iLastBurstTime      = 0;
+                    m_iContinuousFireTime = 0;
+                } else {
+                    m_botCmd.buttons &= ~BUTTON_ATTACKLEFT;
+                }
+            } else {
+                if (bFiring) {
+                    m_iContinuousFireTime += level.intframetime;
+                } else {
+                    m_iContinuousFireTime = 0;
+                }
+
+                if (!m_iLastBurstTime && m_iContinuousFireTime > maxContinousFireTime) {
+                    m_iLastBurstTime      = level.inttime;
+                    m_iContinuousFireTime = 0;
+                }
+            }
+
+            m_iLastFireTime = level.inttime;
+
+            if (pWeap->GetFireType(FIRE_SECONDARY) == FT_MELEE) {
+                if (controlledEnt->client->ps.stats[STAT_AMMO] <= 0
+                    && controlledEnt->client->ps.stats[STAT_CLIPAMMO] <= 0) {
+                    bMelee = true;
+                } else if (fDistanceSquared <= fSecondaryBulletRangeSquared) {
+                    bMelee = true;
+                }
+            }
+
+            if (bMelee) {
+                m_botCmd.buttons &= ~BUTTON_ATTACKLEFT;
+
+                if (fDistanceSquared <= fSecondaryBulletRangeSquared) {
+                    m_botCmd.buttons ^= BUTTON_ATTACKRIGHT;
+                } else {
+                    m_botCmd.buttons &= ~BUTTON_ATTACKRIGHT;
+                }
+            }
+
+            m_iAttackTime        = level.inttime + 1000;
+            m_iAttackStopAimTime = level.inttime + 3000;
+            m_iLastSeenTime      = level.inttime;
+            m_vLastEnemyPos      = m_pEnemy->origin;
+        }
     } else {
         m_botCmd.buttons &= ~(BUTTON_ATTACKLEFT | BUTTON_ATTACKRIGHT);
         fMinDistanceSquared = 0;
+
+        if (level.inttime > m_iLastSeenTime + 2000) {
+            m_iLastUnseenTime = level.inttime;
+        }
     }
 
     if (bCanSee || level.inttime < m_iAttackStopAimTime) {
@@ -835,15 +989,27 @@ void BotController::State_Attack(void)
             // Use the enemy's eyes bone
             m_pEnemy->GetTag(m_iEnemyEyesTag, &eyes_or);
 
-            vRandomOffset = Vector(G_CRandom(8), G_CRandom(8), -G_Random(32));
-            vTarget       = eyes_or.origin + vRandomOffset;
-            rotation.AimAt(eyes_or.origin + vRandomOffset);
+            //vRandomOffset = Vector(G_CRandom(8), G_CRandom(8), -G_Random(32));
+            vTarget = eyes_or.origin;
         } else {
-            vRandomOffset = Vector(G_CRandom(8), G_CRandom(8), 16 + G_Random(m_pEnemy->viewheight - 16));
-            vTarget       = m_pEnemy->origin + vRandomOffset;
+            //vRandomOffset = Vector(G_CRandom(8), G_CRandom(8), 16 + G_Random(m_pEnemy->viewheight - 16));
+            vTarget = m_pEnemy->origin;
         }
 
-        rotation.AimAt(vTarget);
+        if (level.inttime >= m_iLastAimTime + 100) {
+            if (m_iEnemyEyesTag != -1) {
+                m_vAimOffset[0] = G_CRandom((m_pEnemy->maxs.x - m_pEnemy->mins.x) * 0.5);
+                m_vAimOffset[1] = G_CRandom((m_pEnemy->maxs.y - m_pEnemy->mins.y) * 0.5);
+                m_vAimOffset[2] = -G_Random(m_pEnemy->maxs.z * 0.5);
+            } else {
+                m_vAimOffset[0] = G_CRandom((m_pEnemy->maxs.x - m_pEnemy->mins.x) * 0.5);
+                m_vAimOffset[1] = G_CRandom((m_pEnemy->maxs.y - m_pEnemy->mins.y) * 0.5);
+                m_vAimOffset[2] = 16 + G_Random(m_pEnemy->viewheight - 16);
+            }
+            m_iLastAimTime = level.inttime;
+        }
+
+        rotation.AimAt(vTarget + m_vAimOffset);
     } else {
         AimAtAimNode();
     }
@@ -936,13 +1102,13 @@ void BotController::State_BeginWeapon(void)
     SendCommand(va("use \"%s\"", weap->model.c_str()));
 }
 
-Weapon* BotController::FindWeaponWithAmmo() {
-  
-    Weapon *next;
-    int     n;
-    int     j;
-    int     bestrank;
-    Weapon *bestweapon;
+Weapon *BotController::FindWeaponWithAmmo()
+{
+    Weapon               *next;
+    int                   n;
+    int                   j;
+    int                   bestrank;
+    Weapon               *bestweapon;
     const Container<int>& inventory = controlledEnt->getInventory();
 
     n = inventory.NumObjects();
@@ -971,20 +1137,20 @@ Weapon* BotController::FindWeaponWithAmmo() {
             continue;
         }
 
-        bestweapon = (Weapon*)next;
-        bestrank = bestweapon->GetRank();
+        bestweapon = (Weapon *)next;
+        bestrank   = bestweapon->GetRank();
     }
 
     return bestweapon;
 }
 
-Weapon* BotController::FindMeleeWeapon() {
-  
-    Weapon *next;
-    int     n;
-    int     j;
-    int     bestrank;
-    Weapon *bestweapon;
+Weapon *BotController::FindMeleeWeapon()
+{
+    Weapon               *next;
+    int                   n;
+    int                   j;
+    int                   bestrank;
+    Weapon               *bestweapon;
     const Container<int>& inventory = controlledEnt->getInventory();
 
     n = inventory.NumObjects();
@@ -1009,15 +1175,16 @@ Weapon* BotController::FindMeleeWeapon() {
             continue;
         }
 
-        bestweapon = (Weapon*)next;
-        bestrank = bestweapon->GetRank();
+        bestweapon = (Weapon *)next;
+        bestrank   = bestweapon->GetRank();
     }
 
     return bestweapon;
 }
 
-void BotController::UseWeaponWithAmmo() {
-    Weapon* bestWeapon = FindWeaponWithAmmo();
+void BotController::UseWeaponWithAmmo()
+{
+    Weapon *bestWeapon = FindWeaponWithAmmo();
     if (!bestWeapon) {
         //
         // If there is no weapon with ammo, fallback to a weapon that can melee
@@ -1051,7 +1218,7 @@ void BotController::Think()
     G_ClientThink(controlledEnt->edict, &ucmd, &eyeinfo);
 }
 
-void BotController::Killed(Event *ev)
+void BotController::Killed(const Event& ev)
 {
     Entity *attacker;
 
@@ -1068,7 +1235,7 @@ void BotController::Killed(Event *ev)
     m_botEyes.angles[0] = 0;
     m_botEyes.angles[1] = 0;
 
-    attacker = ev->GetEntity(1);
+    attacker = ev.GetEntity(1);
 
     if (attacker && rand() % 5 == 0) {
         // 1/5 chance to go back to the attacker position
@@ -1093,7 +1260,7 @@ void BotController::Killed(Event *ev)
     G_ClientUserinfoChanged(controlledEnt->edict, controlledEnt->client->pers.userinfo);
 }
 
-void BotController::GotKill(Event *ev)
+void BotController::GotKill(const Event& ev)
 {
     ClearEnemy();
     m_iCuriousTime = 0;
@@ -1118,9 +1285,9 @@ void BotController::GotKill(Event *ev)
     }
 }
 
-void BotController::EventStuffText(Event *ev)
+void BotController::EventStuffText(const str& text)
 {
-    SendCommand(ev->GetString(1));
+    SendCommand(text);
 }
 
 void BotController::setControlledEntity(Player *player)
@@ -1128,6 +1295,13 @@ void BotController::setControlledEntity(Player *player)
     controlledEnt = player;
     movement.SetControlledEntity(player);
     rotation.SetControlledEntity(player);
+
+    delegateHandle_gotKill =
+        player->delegate_gotKill.Add(std::bind(&BotController::GotKill, this, std::placeholders::_1));
+    delegateHandle_killed = player->delegate_killed.Add(std::bind(&BotController::Killed, this, std::placeholders::_1));
+    delegateHandle_stufftext =
+        player->delegate_stufftext.Add(std::bind(&BotController::EventStuffText, this, std::placeholders::_1));
+    delegateHandle_spawned = player->delegate_spawned.Add(std::bind(&BotController::Spawned, this));
 }
 
 Player *BotController::getControlledEntity() const
@@ -1198,47 +1372,25 @@ void BotControllerManager::ThinkControllers()
 {
     int i;
 
+    // Delete controllers that don't have associated player entity
+    // This cannot happen unless some mods remove them
+    for (i = controllers.NumObjects(); i > 0; i--) {
+        BotController *controller = controllers.ObjectAt(i);
+        if (!controller->getControlledEntity()) {
+            gi.DPrintf(
+                "Bot %d has no associated player entity. This shouldn't happen unless the entity has been removed by a "
+                "script. The controller will be removed, please fix.\n",
+                i
+            );
+
+            // Remove the controller, it will be recreated later to match `sv_numbots`
+            delete controller;
+            controllers.RemoveObjectAt(i);
+        }
+    }
+
     for (i = 1; i <= controllers.NumObjects(); i++) {
         BotController *controller = controllers.ObjectAt(i);
         controller->Think();
     }
 }
-
-CLASS_DECLARATION(Player, PlayerBot, NULL) {
-    {&EV_Killed,           &PlayerBot::Killed        },
-    {&EV_GotKill,          &PlayerBot::GotKill       },
-    {&EV_Player_StuffText, &PlayerBot::EventStuffText},
-    {NULL,                 NULL                      }
-};
-
-PlayerBot::PlayerBot()
-{
-    entflags |= ECF_BOT;
-    controller = NULL;
-}
-
-void PlayerBot::setController(BotController *controlledBy)
-{
-    controller = controlledBy;
-}
-
-void PlayerBot::Spawned(void)
-{
-    controller->Spawned();
-
-    Player::Spawned();
-}
-
-void PlayerBot::Killed(Event *ev)
-{
-    Player::Killed(ev);
-
-    controller->Killed(ev);
-}
-
-void PlayerBot::GotKill(Event *ev)
-{
-    Player::GotKill(ev);
-
-    controller->GotKill(ev);
-}
