@@ -77,7 +77,7 @@ Event EV_Trigger_SetCount
     EV_DEFAULT,
     "i",
     "count",
-    "Set the amount of times this trigger can be triggered",
+    "Set the number of times this trigger can be triggered",
     EV_NORMAL
 );
 Event EV_Trigger_SetMessage
@@ -440,6 +440,12 @@ void Trigger::TriggerStuff(Event *ev)
         ScriptError("trigger '%s' triggered by self", TargetName().c_str());
     }
 
+    // Fixed in OPM
+    //  Safety check
+    if (other == NULL) {
+        ScriptError("trigger '%s' triggered by NULL entity", TargetName().c_str());
+    }
+
     // Always respond to activate messages from the world since they're probably from
     // the "trigger" command
     if (!respondTo(other) && (other != world || *ev != EV_Activate)
@@ -894,6 +900,12 @@ void TriggerAll::TriggerStuff(Event *ev)
         ScriptError("trigger '%s' triggered by self", TargetName().c_str());
     }
 
+    // Fixed in OPM
+    //  Safety check
+    if (other == NULL) {
+        ScriptError("trigger '%s' triggered by NULL entity", TargetName().c_str());
+    }
+
     // Always respond to activate messages from the world since they're probably from
     // the "trigger" command
     if (!respondTo(other) && !((other == world) && (*ev == EV_Activate))
@@ -1061,6 +1073,7 @@ CLASS_DECLARATION(Trigger, TouchField, NULL) {
 TouchField::TouchField()
 {
     ontouch = NULL;
+    wait = 0;
 }
 
 void TouchField::Setup(Entity *ownerentity, Event& touchevent, Vector min, Vector max, int respondto)
