@@ -1,6 +1,6 @@
 /*
 ===========================================================================
-Copyright (C) 2023 the OpenMoHAA team
+Copyright (C) 2025 the OpenMoHAA team
 
 This file is part of OpenMoHAA source code.
 
@@ -29,8 +29,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110EV_DEFAULT301  U
 #include "player.h"
 #include "../script/scriptexception.h"
 
-static cvar_t *pTurretCameras = NULL;
-
 Event EV_Turret_IdleCheckOffset
 (
     "idleCheckOffset",
@@ -349,6 +347,8 @@ Event EV_Turret_P_SetViewAngles
     EV_NORMAL
 );
 
+static cvar_t *pTurretCameras = NULL;
+
 CLASS_DECLARATION(Weapon, TurretGun, NULL) {
     {&EV_Trigger_Effect,              NULL                                   },
     {&EV_Item_DropToFloor,            &TurretGun::PlaceTurret                },
@@ -448,7 +448,7 @@ TurretGun::TurretGun()
     m_fMaxBurstDelay = 0;
 
     m_fFireToggleTime = level.time;
-    m_iFiring         = 0;
+    m_iFiring         = TURRETFIRESTATE_NONE;
     m_iTargetType     = 0;
 
     // set the camera
@@ -461,7 +461,7 @@ TurretGun::TurretGun()
     m_bHadOwner  = false;
     m_pViewModel = NULL;
 
-    m_iAIState        = 0;
+    m_iAIState        = TURRETAISTATE_DEFAULT;
     m_fAIConvergeTime = g_turret_convergetime->value;
     if (m_fAIConvergeTime < 0) {
         m_fAIConvergeTime = 0;
@@ -573,11 +573,7 @@ void TurretGun::ThinkIdle(void)
 
     m_fIdlePitchSpeed -= level.frametime * 300.0f;
 
-    vNewAngles = Vector(
-        Q_max(angles[0] + level.frametime * m_fIdlePitchSpeed, m_fMaxIdlePitch),
-        angles[1],
-        angles[2]
-    );
+    vNewAngles = Vector(Q_max(angles[0] + level.frametime * m_fIdlePitchSpeed, m_fMaxIdlePitch), angles[1], angles[2]);
 
     vNewAngles.AngleVectorsLeft(&vDir);
     vEnd = origin + vDir * m_vIdleCheckOffset[0];
@@ -787,147 +783,107 @@ bool TurretGun::AI_CanTarget(const vec3_t pos)
 
 void TurretGun::P_ThinkActive(void)
 {
-    Vector vTarg;
-    Vector vTargAngles;
-    Vector vDelta;
-    Vector vAngles;
+    Player *player;
+    float   fDiff;
+    Vector  vTarg;
+    Vector  vTargAngles;
+    Vector  vAngles;
+    Vector  vPos;
+    Vector  vEnd;
+    Vector  vForward;
+    Vector  vMins;
+    Vector  vMaxs;
+    trace_t trace;
 
-    if ((owner) && owner->IsSubclassOfPlayer()) {
-        if (m_vUserViewAng[0] < m_fPitchUpCap) {
-            m_vUserViewAng[0] = m_fPitchUpCap;
-        } else if (m_vUserViewAng[0] > m_fPitchDownCap) {
-            m_vUserViewAng[0] = m_fPitchDownCap;
-        }
-
-        float fDiff = AngleSubtract(m_vUserViewAng[1], m_fStartYaw);
-
-        if (fDiff <= m_fMaxYawOffset) {
-            m_vUserViewAng[1] = fDiff + m_fStartYaw;
-
-            if (-(m_fMaxYawOffset) > fDiff) {
-                m_vUserViewAng[1] = m_fStartYaw - m_fMaxYawOffset;
-            }
-        } else {
-            m_vUserViewAng[1] = m_fMaxYawOffset + m_fStartYaw;
-        }
-
-        owner->SetViewAngles(m_vUserViewAng);
-        vTarg       = owner->GunTarget(false) - origin;
-        vTargAngles = vTarg.toAngles();
-
-        P_SetTargetAngles(vTargAngles);
-    } else if (aim_target) {
-        Vector vNewOfs;
-
-        vDelta  = aim_target->centroid - origin;
-        vNewOfs = vDelta + m_Aim_offset;
-
-        vectoangles(vDelta, vTargAngles);
-        P_SetTargetAngles(vTargAngles);
-
-        if (owner) {
-            Vector forward;
-
-            AngleVectorsLeft(angles, forward, NULL, NULL);
-
-            origin = forward * vNewOfs.length();
-        }
+    // Limit the pitch
+    if (m_vUserViewAng[0] < m_fPitchUpCap) {
+        m_vUserViewAng[0] = m_fPitchUpCap;
+    } else if (m_vUserViewAng[0] > m_fPitchDownCap) {
+        m_vUserViewAng[0] = m_fPitchDownCap;
     }
 
-    if (m_iFiring) {
-        if (m_fMaxBurstTime == 0 || (owner != NULL && owner->client)) {
-            m_iFiring = 2;
-            if (ReadyToFire(FIRE_PRIMARY)) {
-                Fire(FIRE_PRIMARY);
+    //
+    // Limit the yaw
+    //
 
-                if (owner->IsSubclassOfPlayer()) {
-                    m_fCurrViewJitter = m_fViewJitter;
-                }
-            }
-        } else if (m_iFiring != 2) {
-            if (level.time > m_fFireToggleTime) {
-                m_iFiring         = 2;
-                m_fFireToggleTime = G_Random(m_fMaxBurstTime - m_fMinBurstTime) + (level.time + m_fMinBurstTime);
-            }
-        } else if (ReadyToFire(FIRE_PRIMARY)) {
+    fDiff = AngleSubtract(m_vUserViewAng[1], m_fStartYaw);
+    fDiff = Q_clamp_float(fDiff, -m_fMaxYawOffset, m_fMaxYawOffset);
+
+    m_vUserViewAng[1] = m_fStartYaw + fDiff;
+
+    // Set the user's view angles
+    owner->SetViewAngles(m_vUserViewAng);
+
+    //
+    // Set the weapon angles to make it point straight
+    // to the user's target
+    //
+
+    vTarg       = owner->GunTarget(false) - origin;
+    vTargAngles = vTarg.toAngles();
+    P_SetTargetAngles(vTargAngles);
+
+    // Handle firing
+    if (m_iFiring != TURRETFIRESTATE_NONE) {
+        m_iFiring = TURRETFIRESTATE_FIRING;
+
+        if (ReadyToFire(FIRE_PRIMARY)) {
             Fire(FIRE_PRIMARY);
-
-            if (owner->IsSubclassOfPlayer()) {
-                m_fCurrViewJitter = m_fViewJitter;
-            }
-        } else if (level.time > m_fFireToggleTime) {
-            m_iFiring         = 1;
-            m_fFireToggleTime = G_Random(m_fMaxBurstDelay - m_fMaxBurstDelay) + (level.time + m_fMinBurstDelay);
+            m_fCurrViewJitter = m_fViewJitter;
         }
     }
 
-    if (owner && owner->IsSubclassOfPlayer()) {
-        vAngles = m_vUserViewAng;
+    //
+    // Setup the camera
+    //
 
-        if (!m_pUserCamera) {
-            m_pUserCamera = new Camera;
-        }
+    player  = static_cast<Player *>(owner.Pointer());
+    vAngles = m_vUserViewAng;
 
-        if (m_fCurrViewJitter > 0.0f) {
-            float x = (float)(rand() & 0x7FFF);
-            float y = (float)(rand() & 0x7FFF);
-            float z = (float)(rand() & 0x7FFF);
-
-            vAngles[0] += (x * 0.00003f + x * 0.00003f - 1.0f) * m_fCurrViewJitter;
-            vAngles[1] += (y * 0.00003f + y * 0.00003f - 1.0f) * m_fCurrViewJitter;
-            vAngles[2] += (z * 0.00003f + z * 0.00003f - 1.0f) * m_fCurrViewJitter;
-
-            m_fCurrViewJitter -= level.frametime * 6.0f;
-
-            if (m_fCurrViewJitter < 0.0f) {
-                m_fCurrViewJitter = 0.0f;
-            }
-        }
-
-        m_pUserCamera->setOrigin(origin);
-        m_pUserCamera->setAngles(vAngles);
-        m_pUserCamera->SetPositionOffset(m_vViewOffset);
-
-        owner->client->ps.camera_flags |= CF_CAMERA_ANGLES_TURRETMODE;
-
-        Player *player = (Player *)owner.Pointer();
-
-        if (!player->IsZoomed()) {
-            player->ToggleZoom(80);
-        }
+    if (!m_pUserCamera) {
+        m_pUserCamera = new Camera;
     }
 
-    if (owner && owner->client) {
-        Vector  vPos;
-        Vector  vEnd;
-        Vector  vAng;
-        Vector  vForward;
-        Vector  vMins;
-        Vector  vMaxs;
-        trace_t trace;
+    P_ApplyFiringViewJitter(vAngles);
 
-        Vector(0, angles[1], 0).AngleVectorsLeft(&vForward);
+    m_pUserCamera->setOrigin(origin);
+    m_pUserCamera->setAngles(vAngles);
+    m_pUserCamera->SetPositionOffset(m_vViewOffset);
 
-        vPos = origin - vForward * m_fUserDistance;
-        vPos[2] -= 16.0f;
+    owner->client->ps.camera_flags |= CF_CAMERA_ANGLES_TURRETMODE;
 
-        vEnd = vPos;
-        vEnd[2] -= 64.0f;
+    if (!player->IsZoomed()) {
+        player->ToggleZoom(80);
+    }
 
-        vMins    = owner->mins;
-        vMaxs    = owner->maxs;
-        vMaxs[2] = owner->mins[2] + 4.0f;
+    //
+    // Position the player appropriately
+    // so it looks like they're holding the turret
+    //
 
-        trace = G_Trace(vPos, vMins, vMaxs, vEnd, owner, MASK_PLAYERSOLID, qtrue, "TurretGun::ThinkActive 1");
+    Vector(0, angles[1], 0).AngleVectorsLeft(&vForward);
 
-        vPos = trace.endpos;
+    vPos = origin - vForward * m_fUserDistance;
+    vPos[2] -= 16.0f;
 
-        trace =
-            G_Trace(vPos, owner->mins, owner->maxs, vPos, owner, MASK_PLAYERSOLID, qtrue, "TurretGun::ThinkActive 2");
+    vEnd = vPos;
+    vEnd[2] -= 64.0f;
 
-        if (!trace.allsolid && !trace.startsolid) {
-            owner->setOrigin(vPos);
-        }
+    vMins    = owner->mins;
+    vMaxs    = owner->maxs;
+    vMaxs[2] = owner->mins[2] + 4.0f;
+
+    trace = G_Trace(vPos, vMins, vMaxs, vEnd, owner, MASK_PLAYERSOLID, qtrue, "TurretGun::P_ThinkActive 1");
+
+    vPos = trace.endpos;
+
+    //
+    // Test position, to avoid positioning the player inside a solid object
+    //
+    trace = G_Trace(vPos, owner->mins, owner->maxs, vPos, owner, MASK_PLAYERSOLID, qtrue, "TurretGun::P_ThinkActive 2");
+
+    if (!trace.allsolid && !trace.startsolid) {
+        owner->setOrigin(vPos);
     }
 }
 
@@ -967,7 +923,7 @@ void TurretGun::AI_MoveToDefaultPosition()
 
 void TurretGun::AI_DoTargetAutoDefault()
 {
-    m_iFiring = 0;
+    m_iFiring = TURRETFIRESTATE_NONE;
     if (owner->m_Enemy) {
         Actor *actor = static_cast<Actor *>(owner.Pointer());
         if (actor->CanSeeEnemy(200)) {
@@ -980,14 +936,14 @@ void TurretGun::AI_DoTargetAutoDefault()
 
 void TurretGun::AI_StartDefault()
 {
-    m_iFiring  = 0;
-    m_iAIState = 0;
+    m_iFiring  = TURRETFIRESTATE_NONE;
+    m_iAIState = TURRETAISTATE_DEFAULT;
 }
 
 void TurretGun::AI_StartSuppress()
 {
     m_iAIStartSuppressTime = level.inttime;
-    m_iAIState             = 2;
+    m_iAIState             = TURRETAISTATE_SUPPRESS;
     VectorCopy(m_vAIDesiredTargetPosition, m_vAITargetPosition);
     VectorClear(m_vAICurrentTargetPosition);
     VectorClear(m_vAITargetSpeed);
@@ -997,15 +953,15 @@ void TurretGun::AI_StartSuppress()
 void TurretGun::AI_StartSuppressWait()
 {
     m_iAIStartSuppressTime = level.inttime;
-    m_iAIState             = 3;
+    m_iAIState             = TURRETAISTATE_SUPPRESS_WAIT;
 }
 
 void TurretGun::AI_StartTrack()
 {
-    if (m_iAIState == 0) {
+    if (m_iAIState == TURRETAISTATE_DEFAULT) {
         m_iAILastTrackTime = level.inttime;
     }
-    m_iAIState = 1;
+    m_iAIState = TURRETAISTATE_TRACK;
 }
 
 void TurretGun::AI_DoTargetAutoTrack()
@@ -1034,8 +990,8 @@ void TurretGun::AI_DoTargetAutoTrack()
         return;
     }
 
-    if (m_iFiring == 0) {
-        m_iFiring = 1;
+    if (m_iFiring == TURRETFIRESTATE_NONE) {
+        m_iFiring = TURRETFIRESTATE_BEGIN_FIRE;
     }
 
     end = owner->m_Enemy->centroid;
@@ -1167,15 +1123,15 @@ void TurretGun::AI_DoTargetAutoSuppress()
         return;
     }
 
-    if (m_iFiring == 0) {
-        m_iFiring = 1;
+    if (m_iFiring == TURRETFIRESTATE_NONE) {
+        m_iFiring = TURRETFIRESTATE_BEGIN_FIRE;
     }
     AI_DoSuppressionAiming();
 }
 
 void TurretGun::AI_DoTargetAutoSuppressWait()
 {
-    m_iFiring = 0;
+    m_iFiring = TURRETFIRESTATE_NONE;
     Actor *actor;
 
     if (!owner->m_Enemy) {
@@ -1249,8 +1205,8 @@ void TurretGun::AI_DoFiring()
         // Removed in 2.0
         //  The fire delay is always constant on 1.11 and below
         //
-        if (m_iFiring == 1) {
-            m_iFiring = 4;
+        if (m_iFiring == TURRETFIRESTATE_BEGIN_FIRE) {
+            m_iFiring = TURRETFIRESTATE_FIRING;
         }
 
         if (IsFiring() && ReadyToFire(FIRE_PRIMARY)) {
@@ -1260,8 +1216,8 @@ void TurretGun::AI_DoFiring()
         return;
     }
 
-    minBurstTime = m_fMinBurstTime;
-    maxBurstTime = m_fMaxBurstTime;
+    minBurstTime  = m_fMinBurstTime;
+    maxBurstTime  = m_fMaxBurstTime;
     minBurstDelay = m_fMinBurstDelay;
     maxBurstDelay = m_fMaxBurstDelay;
 
@@ -1272,24 +1228,29 @@ void TurretGun::AI_DoFiring()
         maxBurstDelay = minBurstDelay = fire_delay[FIRE_PRIMARY] / 10.f;
     }
 
-    if (m_iFiring == 1) {
+    switch (m_iFiring) {
+    case TURRETFIRESTATE_BEGIN_FIRE:
         if (m_fMaxBurstTime > 0) {
             if (m_fFireToggleTime < level.time) {
-                m_iFiring         = 4;
+                m_iFiring         = TURRETFIRESTATE_FIRING;
                 m_fFireToggleTime = level.time + m_fMinBurstTime + (m_fMaxBurstTime - m_fMinBurstTime) * random();
             }
         } else {
-            m_iFiring = 4;
+            m_iFiring = TURRETFIRESTATE_FIRING;
         }
-    } else if (m_iFiring == 4) {
+        break;
+    case TURRETFIRESTATE_FIRING:
         Fire(FIRE_PRIMARY);
 
         if (m_fMaxBurstTime > 0) {
             if (m_fFireToggleTime < level.time) {
-                m_iFiring         = 1;
+                m_iFiring         = TURRETFIRESTATE_BEGIN_FIRE;
                 m_fFireToggleTime = level.time + m_fMinBurstDelay + (m_fMaxBurstDelay - m_fMinBurstDelay) * random();
             }
         }
+        break;
+    default:
+        break;
     }
 }
 
@@ -1329,11 +1290,11 @@ void TurretGun::P_UserAim(usercmd_t *ucmd)
     m_vUserLastCmdAng = vNewCmdAng;
 
     if (ucmd->buttons & BUTTON_ATTACKLEFT) {
-        if (m_iFiring == 0) {
-            m_iFiring = 1;
+        if (m_iFiring == TURRETFIRESTATE_NONE) {
+            m_iFiring = TURRETFIRESTATE_BEGIN_FIRE;
         }
     } else {
-        m_iFiring = 0;
+        m_iFiring = TURRETFIRESTATE_NONE;
     }
 
     flags |= FL_THINK;
@@ -1425,7 +1386,7 @@ void TurretGun::AI_TurretEndUsed()
 
     m_fIdlePitchSpeed = 0;
     m_iIdleHitCount   = 0;
-    m_iFiring         = 0;
+    m_iFiring         = TURRETFIRESTATE_NONE;
 }
 
 void TurretGun::RemoveUserCamera()
@@ -1465,7 +1426,7 @@ void TurretGun::P_TurretEndUsed()
 
     m_fIdlePitchSpeed = 0;
     m_iIdleHitCount   = 0;
-    m_iFiring         = 0;
+    m_iFiring         = TURRETFIRESTATE_NONE;
 
     yawCap = AngleSubtract(angles[1], m_fStartYaw);
     if (yawCap > m_fMaxIdleYaw) {
@@ -1494,7 +1455,7 @@ void TurretGun::P_TurretUsed(Player *player)
     if (owner) {
         if (owner == player) {
             P_TurretEndUsed();
-            m_iFiring = 0;
+            m_iFiring = TURRETFIRESTATE_NONE;
         }
     } else {
         m_vUserViewAng = player->GetViewAngles();
@@ -1507,7 +1468,7 @@ void TurretGun::P_TurretUsed(Player *player)
             P_TurretBeginUsed(player);
 
             flags &= ~FL_THINK;
-            m_iFiring = 0;
+            m_iFiring = TURRETFIRESTATE_NONE;
             m_UseThread.Execute(this);
         }
     }
@@ -1594,14 +1555,14 @@ void TurretGun::AI_EventClearAimTarget(Event *ev)
 
 void TurretGun::AI_EventStartFiring(Event *ev)
 {
-    if (m_iFiring == 0) {
-        m_iFiring = 1;
+    if (m_iFiring == TURRETFIRESTATE_NONE) {
+        m_iFiring = TURRETFIRESTATE_BEGIN_FIRE;
     }
 }
 
 void TurretGun::AI_EventStopFiring(Event *ev)
 {
-    m_iFiring = 0;
+    m_iFiring = TURRETFIRESTATE_NONE;
 }
 
 void TurretGun::AI_EventTurnSpeed(Event *ev)
@@ -1660,7 +1621,7 @@ void TurretGun::AI_EventBurstFireSettings(Event *ev)
 
 bool TurretGun::IsFiring(void)
 {
-    return m_iFiring == 4;
+    return m_iFiring == TURRETFIRESTATE_FIRING;
 }
 
 void TurretGun::P_ApplyFiringViewJitter(Vector& vAng)
@@ -1770,7 +1731,7 @@ void TurretGun::P_CreateViewModel(void)
     m_pViewModel->setScale(edict->s.scale);
     m_pViewModel->detach_at_death = qtrue;
     m_pViewModel->setModel(newmodel);
-    m_pViewModel->edict->s.renderfx |= RF_VIEWMODEL;
+    m_pViewModel->edict->s.renderfx |= RF_ALWAYSDRAW;
 
     if (!m_pViewModel->edict->tiki) {
         m_pViewModel->Delete();
@@ -2025,7 +1986,7 @@ void TurretGun::AI_EventSetTargetType(Event *ev)
     }
 
     if (targettype != m_iTargetType) {
-        m_iFiring     = 0;
+        m_iFiring     = TURRETFIRESTATE_NONE;
         m_iTargetType = targettype;
     }
 }
