@@ -70,6 +70,11 @@ void Alias_ListClear(AliasList_t *list)
     }
 
     for (node = list->data_list; node != NULL; node = next) {
+        if (node->subtitle) {
+            // Added in OPM
+            Z_Free(node->subtitle);
+        }
+
         next = node->next;
         Z_Free(node);
     }
@@ -348,69 +353,38 @@ qboolean Alias_ListAdd(AliasList_t *list, const char *alias, const char *name, c
     return qtrue;
 }
 
+static int Alias_ListCompareNodes(const void *a1, const void *a2)
+{
+    const AliasListNode_t *ptr1 = *(const AliasListNode_t **)a1;
+    const AliasListNode_t *ptr2 = *(const AliasListNode_t **)a2;
+
+    return strcmp(ptr1->alias_name, ptr2->alias_name);
+}
+
 void Alias_ListSort(AliasList_t *list)
 {
-    int              num;
-    int              size;
-    int              i;
-    AliasListNode_t *root;
     AliasListNode_t *ptr;
-    AliasListNode_t *smallest = NULL;
-    AliasListNode_t *prev;
-    AliasListNode_t *smallprev;
-    AliasListNode_t *last = NULL;
+    int              num;
+    int              i;
 
     if (!list->dirty) {
         return;
     }
 
-    num = 0;
-
-    root            = list->data_list;
-    list->data_list = NULL;
     if (list->sorted_list) {
         Z_Free(list->sorted_list);
     }
 
-    size              = list->num_in_list * sizeof(AliasListNode_t *);
-    list->sorted_list = Z_TagMalloc(size, TAG_TIKI);
-    memset(list->sorted_list, 0, size);
+    num = list->num_in_list;
 
-    for (i = 0; i < list->num_in_list; i++) {
-        prev      = root;
-        smallprev = root;
+    list->sorted_list = Z_TagMalloc(num * sizeof(AliasListNode_t *), TAG_TIKI);
 
-        for (ptr = root->next; ptr != NULL; ptr = ptr->next) {
-            if (strcmp(ptr->alias_name, smallprev->alias_name) < 0) {
-                smallest  = prev;
-                smallprev = ptr;
-            }
-
-            prev = ptr;
-        }
-
-        if (smallprev == root) {
-            root = smallprev->next;
-        } else {
-            smallest->next = smallprev->next;
-        }
-
-        if (!last || strcmp(last->alias_name, smallprev->alias_name)) {
-            list->sorted_list[num++] = smallprev;
-            smallprev->next          = list->data_list;
-            list->data_list          = smallprev;
-            last                     = smallprev;
-        } else {
-            if (strcmp(last->real_name, smallprev->real_name)) {
-                Com_DPrintf("Duplicate Aliases for %s in list %s  Last: %p.\n", last->alias_name, list->name, last);
-            }
-
-            Z_Free(smallprev);
-        }
+    for (i = 0, ptr = list->data_list; i < num; i++, ptr = ptr->next) {
+        list->sorted_list[i] = ptr;
     }
 
-    list->dirty       = 0;
-    list->num_in_list = num;
+    qsort(list->sorted_list, num, sizeof(AliasListNode_t *), Alias_ListCompareNodes);
+    list->dirty = 0;
 }
 
 const char *Alias_ListFind(AliasList_t *list, const char *alias)
@@ -544,73 +518,73 @@ void Alias_ListFindRandomRange(
 
     length = strlen(alias);
 
-    if (length > MAX_ALIASLIST_NAME_LENGTH) {
+    if (length + 1 > MAX_ALIASLIST_NAME_LENGTH) {
         return;
     }
 
-    for (index = 0; index < length; index++) {
-        convalias[index] = tolower(alias[index]);
+    for (i = 0; i < length; i++) {
+        convalias[i] = tolower(alias[i]);
     }
 
     convalias[length] = 0;
 
     l = 0;
     r = list->num_in_list - 1;
-    if (r >= 0) {
-        do {
-            index = (l + r) >> 1;
-            diff  = strncmp(convalias, list->sorted_list[index]->alias_name, length);
+    while (r >= l) {
+        index = (l + r) >> 1;
+        diff  = strncmp(convalias, list->sorted_list[index]->alias_name, length);
 
-            if (diff == 0) {
-                break;
-            } else if (diff > 0) {
-                l = index + 1;
-            } else {
-                r = index - 1;
-            }
-        } while (r >= l);
-
-        if (r >= l) {
-            numfound         = 0;
-            *min_index       = index;
-            *max_index       = index;
-            totalfoundweight = 0.f;
-
-            ptr = &list->sorted_list[index];
-            for (i = index + 1; i > 0; i--, ptr--) {
-                if (strncmp(convalias, (*ptr)->alias_name, length)) {
-                    break;
-                }
-
-                if (numfound < ARRAY_LEN(foundlist) && (*ptr)->alias_name[length] != '_') {
-                    foundlist[numfound++] = *ptr;
-                    totalfoundweight += (*ptr)->weight;
-                    *min_index = i - 1;
-                }
-            }
-
-            ptr = &list->sorted_list[index + 1];
-
-            for (i = index + 1; i < list->num_in_list; i++, ptr++) {
-                if (strncmp(convalias, (*ptr)->alias_name, length)) {
-                    break;
-                }
-
-                if (numfound < ARRAY_LEN(foundlist) && (*ptr)->alias_name[length] != '_') {
-                    foundlist[numfound++] = *ptr;
-                    totalfoundweight += (*ptr)->weight;
-                    *max_index = i;
-                }
-            }
-
-            if (numfound) {
-                *total_weight = totalfoundweight;
-            } else {
-                *min_index = -1;
-                *max_index = -1;
-            }
+        if (diff == 0) {
+            break;
+        } else if (diff > 0) {
+            l = index + 1;
+        } else {
+            r = index - 1;
         }
     }
+
+    if (r < l) {
+        return;
+    }
+
+    numfound         = 0;
+    *min_index       = index;
+    *max_index       = index;
+    totalfoundweight = 0.f;
+
+    ptr = &list->sorted_list[index];
+    for (i = index + 1; i > 0; i--, ptr--) {
+        if (strncmp(convalias, (*ptr)->alias_name, length)) {
+            break;
+        }
+
+        if (numfound < ARRAY_LEN(foundlist) && (*ptr)->alias_name[length] != '_') {
+            foundlist[numfound++] = *ptr;
+            totalfoundweight += (*ptr)->weight;
+            *min_index = i - 1;
+        }
+    }
+
+    ptr = &list->sorted_list[index + 1];
+    for (i = index + 1; i < list->num_in_list; i++, ptr++) {
+        if (strncmp(convalias, (*ptr)->alias_name, length)) {
+            break;
+        }
+
+        if (numfound < ARRAY_LEN(foundlist) && (*ptr)->alias_name[length] != '_') {
+            foundlist[numfound++] = *ptr;
+            totalfoundweight += (*ptr)->weight;
+            *max_index = i;
+        }
+    }
+
+    if (!numfound) {
+        *min_index = -1;
+        *max_index = -1;
+        return;
+    }
+
+    *total_weight = totalfoundweight;
 }
 
 void Alias_ListDump(AliasList_t *list)
