@@ -1355,7 +1355,7 @@ void R_Register( void )
 	r_maxmode = ri.Cvar_Get("r_maxmode", "6", CVAR_ARCHIVE | CVAR_LATCH);
 	r_vidmode1024 = ri.Cvar_Get("r_vidmode1024", "1", CVAR_ARCHIVE | CVAR_LATCH);
 	r_vidmodemax = ri.Cvar_Get("r_vidmodemax", "1", CVAR_ARCHIVE | CVAR_LATCH);
-	r_mode = ri.Cvar_Get("r_mode", "3", CVAR_ARCHIVE | CVAR_LATCH);
+	r_mode = ri.Cvar_Get("r_mode", "-2", CVAR_ARCHIVE | CVAR_LATCH);
 	
 	// Added in 2.0
 	//  But removed because it's kind of annoying
@@ -1402,9 +1402,12 @@ void R_Register( void )
 	r_dlightBacks = ri.Cvar_Get( "r_dlightBacks", "1", CVAR_ARCHIVE );
 	r_finish = ri.Cvar_Get ("r_finish", "0", CVAR_ARCHIVE);
 	r_textureMode = ri.Cvar_Get( "r_textureMode", "GL_LINEAR_MIPMAP_NEAREST", CVAR_ARCHIVE );
-	r_swapInterval = ri.Cvar_Get( "r_swapInterval", "0", CVAR_ARCHIVE );
+	r_swapInterval = ri.Cvar_Get( "r_swapInterval", "0", CVAR_ARCHIVE | CVAR_LATCH );
 	r_gamma = ri.Cvar_Get( "r_gamma", "1", CVAR_ARCHIVE );
 	r_facePlaneCull = ri.Cvar_Get ("r_facePlaneCull", "1", CVAR_ARCHIVE );
+	//	Added in OPM
+	//	 Make archivable
+	r_drawstaticdecals = ri.Cvar_Get("r_drawstaticdecals", "0", CVAR_ARCHIVE );
 
 	r_primitives = ri.Cvar_Get( "r_primitives", "0", CVAR_ARCHIVE );
 
@@ -1470,8 +1473,7 @@ void R_Register( void )
 	r_drawstaticmodels = ri.Cvar_Get("r_drawstaticmodels", "1", CVAR_CHEAT);
 	r_drawstaticmodelpoly = ri.Cvar_Get("r_drawstaticmodelpoly", "1", CVAR_CHEAT);
 	r_drawbrushes = ri.Cvar_Get("r_drawbrushes", "1", CVAR_CHEAT);
-	r_drawbrushmodels = ri.Cvar_Get("r_drawbrushmodels", "1", CVAR_CHEAT);
-	r_drawstaticdecals = ri.Cvar_Get("r_drawstaticdecals", "0", 0);
+	r_drawbrushmodels = ri.Cvar_Get("r_drawbrushmodels", "1", CVAR_CHEAT);	
 	r_drawterrain = ri.Cvar_Get("r_drawterrain", "1", CVAR_CHEAT);
 	r_drawsprites = ri.Cvar_Get("r_drawsprites", "1", CVAR_CHEAT);
 	r_drawspherelights = ri.Cvar_Get("r_drawspherelights", "1", CVAR_CHEAT);
@@ -1590,6 +1592,7 @@ void R_Register( void )
 
 void R_InitExtensions() {
 	// FIXME: qglTextureEnvCombineExists
+#if 0
 	glState.cntTexEnvExt = 0;
 	glState.cntnvblendmode = 0;
 
@@ -1601,6 +1604,7 @@ void R_InitExtensions() {
 	qglTexEnvf(GL_TEXTURE_ENV, GL_OPERAND1_RGB, 0x44400000);
 	qglTexEnvf(GL_TEXTURE_ENV, GL_SOURCE2_RGB, 0x47057700);
 	qglTexEnvf(GL_TEXTURE_ENV, GL_OPERAND2_RGB, 770.0);
+#endif
 }
 
 /*
@@ -1964,5 +1968,8 @@ refexport_t *GetRefAPI ( int apiVersion, refimport_t *rimp ) {
 	re.ImageExists = R_ImageExists;
 	re.CountTextureMemory = R_CountTextureMemory;
 
+    re.LoadRawImage = R_LoadRawImage;
+    re.FreeRawImage = R_FreeRawImage;
+
 	return &re;
 }
