@@ -228,6 +228,8 @@ cvar_t	*r_saveFontData;
 
 cvar_t	*r_marksOnTriangleMeshes;
 
+cvar_t	*r_vaoCache;
+
 cvar_t	*r_aviMotionJpegQuality;
 cvar_t	*r_screenshotJpegQuality;
 
@@ -1534,6 +1536,8 @@ void R_Register( void )
 
 	r_marksOnTriangleMeshes = ri.Cvar_Get("r_marksOnTriangleMeshes", "0", CVAR_ARCHIVE);
 
+	r_vaoCache = ri.Cvar_Get("r_vaoCache", "0", CVAR_ARCHIVE);
+
 	r_aviMotionJpegQuality = ri.Cvar_Get("r_aviMotionJpegQuality", "90", CVAR_ARCHIVE);
 	r_screenshotJpegQuality = ri.Cvar_Get("r_screenshotJpegQuality", "90", CVAR_ARCHIVE);
 
@@ -1937,6 +1941,7 @@ RE_GetGraphicsInfo
 const char* RE_GetGraphicsInfo() {
 	// FIXME: unimplemented (GL2)
 	// Looks like it's unused anyway
+	return "";
 }
 
 //=========================
@@ -1986,16 +1991,16 @@ refexport_t *GetRefAPI ( int apiVersion, refimport_t *rimp ) {
 	re.ModelBounds = R_ModelBounds;
 
 	re.ClearScene = RE_ClearScene;
-	re.AddRefEntityToScene = RE_AddRefEntityToScene;
-	re.AddPolyToScene = RE_AddPolyToScene;
+	re.AddRefEntityToScene = RE_AddRefEntityToScene2;
+	re.AddPolyToScene = RE_AddPolyToScene2;
 	re.LightForPoint = R_LightForPoint;
-	re.AddLightToScene = RE_AddLightToScene;
+	re.AddLightToScene = RE_AddLightToScene2;
 	re.AddAdditiveLightToScene = RE_AddAdditiveLightToScene;
 	re.RenderScene = RE_RenderScene;
 
 	re.SetColor = RE_SetColor;
 	re.DrawStretchPic = RE_StretchPic;
-	re.DrawStretchRaw = RE_StretchRaw;
+	re.DrawStretchRaw = RE_StretchRaw2;
 	re.UploadCinematic = RE_UploadCinematic;
 
 	re.RegisterFont = RE_RegisterFont;
@@ -2037,7 +2042,7 @@ refexport_t *GetRefAPI ( int apiVersion, refimport_t *rimp ) {
 	re.SetColor = Draw_SetColor;
 	re.DrawStretchPic = Draw_StretchPic;
 	re.DrawStretchPic2 = Draw_StretchPic2;
-	re.DrawStretchRaw = RE_StretchRaw;
+	re.DrawStretchRaw = RE_StretchRaw2;
 	re.DebugLine = R_DebugLine;
 	re.DrawTilePic = Draw_TilePic;
 	re.DrawTilePicOffset = Draw_TilePicOffset;
@@ -2071,5 +2076,8 @@ refexport_t *GetRefAPI ( int apiVersion, refimport_t *rimp ) {
 	re.ImageExists = R_ImageExists;
 	re.CountTextureMemory = R_CountTextureMemory;
 
+    re.LoadRawImage = R_LoadRawImage;
+    re.FreeRawImage = R_FreeRawImage;
+
 	return &re;
 }
