@@ -141,7 +141,7 @@ static void R_InterpolateVert(terraTri_t *pTri, terrainVert_t *pVert)
     pMinHeight  = (byte *)Q_min((uintptr_t)pVert0->pHgt, (uintptr_t)pVert1->pHgt);
     pMaxHeight  = (byte *)Q_max((uintptr_t)pVert0->pHgt, (uintptr_t)pVert1->pHgt);
     pVert->pHgt = (byte *)(pMinHeight + ((pMaxHeight - pMinHeight) >> 1));
-    assert(pVert->pHgt >= pMinHeight && pVert->pHgt < pMaxHeight);
+    assert(pVert->pHgt >= pMinHeight && pVert->pHgt < pMaxHeight || pMinHeight == pMaxHeight);
 
     // Calculate the average Z
     pVert->fHgtAvg = (float)(*pVert0->pHgt + *pVert1->pHgt);
@@ -998,7 +998,7 @@ static void R_DoTriSplitting()
                 //
                 // make sure there are sufficient number of tris
                 //
-                if (g_tri.nFree < 14 || g_vert.nFree < 14) {
+                if (g_tri.nFree < 14*2 || g_vert.nFree < 14) {
                     ri.Printf(PRINT_DEVELOPER, "WARNING: aborting terrain tessellation -- insufficient tris\n");
                     return;
                 }
