@@ -602,58 +602,81 @@ variabletype ScriptVariable::GetType() const
     return (variabletype)type;
 }
 
-qboolean ScriptVariable::IsEntity(void)
+bool ScriptVariable::IsNone() const
 {
-    if (type == VARIABLE_LISTENER) {
-        if (!m_data.listenerValue->Pointer()
-#if defined(GAME_DLL)
-            || checkInheritance(Entity::classinfostatic(), m_data.listenerValue->Pointer()->classinfo())
-#endif
-        ) {
-            return true;
-        }
-    }
-
-    return false;
+    return type == VARIABLE_NONE;
 }
 
-qboolean ScriptVariable::IsListener(void)
+bool ScriptVariable::HasValue() const
+{
+    return type != VARIABLE_NONE;
+}
+
+bool ScriptVariable::IsEntity(void) const
+{
+    if (type != VARIABLE_LISTENER) {
+        return false;
+    }
+
+    if (!m_data.listenerValue->Pointer()) {
+        // Fixed in OPM
+        //  Not sure why OG returns true
+        return false;
+    }
+#if defined(GAME_DLL)
+    if (!checkInheritance(Entity::classinfostatic(), m_data.listenerValue->Pointer()->classinfo())) {
+        return false;
+    }
+#endif
+
+    return true;
+}
+
+bool ScriptVariable::IsListener(void) const
 {
     return type == VARIABLE_LISTENER;
 }
 
-qboolean ScriptVariable::IsNumeric(void)
+bool ScriptVariable::IsNumeric(void) const
 {
     return type == VARIABLE_INTEGER || type == VARIABLE_FLOAT;
 }
 
-qboolean ScriptVariable::IsConstArray() const
+bool ScriptVariable::IsConstArray() const
 {
     return type == VARIABLE_CONSTARRAY || type == VARIABLE_CONTAINER || type == VARIABLE_SAFECONTAINER;
 }
 
 #ifdef WITH_SCRIPT_ENGINE
 
-qboolean ScriptVariable::IsSimpleEntity(void)
+bool ScriptVariable::IsSimpleEntity(void) const
 {
-    if (type == VARIABLE_LISTENER) {
-        if (!m_data.listenerValue->Pointer()
-            || checkInheritance(&SimpleEntity::ClassInfo, m_data.listenerValue->Pointer()->classinfo())) {
-            return true;
-        }
+    if (type != VARIABLE_LISTENER) {
+        return false;
     }
 
-    return false;
+    if (!m_data.listenerValue->Pointer()) {
+        // Fixed in OPM
+        //  Not sure why OG returns true
+        return false;
+    }
+#    if defined(GAME_DLL)
+    if (!checkInheritance(Entity::classinfostatic(), m_data.listenerValue->Pointer()->classinfo())) {
+        return false;
+    }
+#    endif
+
+    return true;
 }
 
 #endif
 
-qboolean ScriptVariable::IsString(void)
+bool ScriptVariable::IsString(void) const
 {
     return (type == VARIABLE_STRING || type == VARIABLE_CONSTSTRING);
 }
 
-qboolean ScriptVariable::IsVector(void)
+bool ScriptVariable::IsVector(void) const
 {
     return type == VARIABLE_VECTOR;
 }
@@ -1533,10 +1556,9 @@ void ScriptVariable::operator+=(const ScriptVariable& value)
     case VARIABLE_STRING
         + VARIABLE_LISTENER *VARIABLE_MAX: // ( string )			+		( listener )
     case VARIABLE_CONSTSTRING
-        + VARIABLE_LISTENER                *VARIABLE_MAX: // ( const string )		+		( listener )
-    case VARIABLE_STRING + VARIABLE_VECTOR *VARIABLE_MAX: // ( string )			+		( vector )
-    case VARIABLE_CONSTSTRING
-        + VARIABLE_VECTOR *VARIABLE_MAX: // ( const string )		+		( vector )
+        + VARIABLE_LISTENER                     *VARIABLE_MAX: // ( const string )		+		( listener )
+    case VARIABLE_STRING + VARIABLE_VECTOR      *VARIABLE_MAX: // ( string )			+		( vector )
+    case VARIABLE_CONSTSTRING + VARIABLE_VECTOR *VARIABLE_MAX: // ( const string )		+		( vector )
         setStringValue(stringValue() + value.stringValue());
         break;
 
@@ -1742,7 +1764,9 @@ void ScriptVariable::operator%=(const ScriptVariable& value)
         Clear();
 
         throw ScriptException(
-            "binary '%%' applied to incompatible types '%s' and '%s'", typenames[currentType], typenames[value.GetType()]
+            "binary '%%' applied to incompatible types '%s' and '%s'",
+            typenames[currentType],
+            typenames[value.GetType()]
         );
 
         break;
@@ -1988,13 +2012,13 @@ bool ScriptVariable::operator==(const ScriptVariable& value)
         return m_data.intValue == value.m_data.intValue;
 
     case VARIABLE_INTEGER + VARIABLE_FLOAT *VARIABLE_MAX: // ( int ) == ( float )
-        return m_data.intValue == value.m_data.floatValue;
+        return fabs(m_data.intValue - value.m_data.floatValue) < 0.0001;
 
     case VARIABLE_FLOAT + VARIABLE_FLOAT *VARIABLE_MAX: // ( float ) == ( float )
-        return m_data.floatValue == value.m_data.floatValue;
+        return fabs(m_data.floatValue - value.m_data.floatValue) < 0.0001;
 
     case VARIABLE_FLOAT + VARIABLE_INTEGER *VARIABLE_MAX: // ( float ) == ( int )
-        return m_data.floatValue == value.m_data.intValue;
+        return fabs(m_data.floatValue - value.m_data.intValue) < 0.0001;
 
     case VARIABLE_CONSTSTRING
         + VARIABLE_CONSTSTRING *VARIABLE_MAX: // ( const string )		==		( const string )
@@ -2005,9 +2029,8 @@ bool ScriptVariable::operator==(const ScriptVariable& value)
         + VARIABLE_STRING                 *VARIABLE_MAX: // ( int )				==		( string )
     case VARIABLE_FLOAT + VARIABLE_STRING *VARIABLE_MAX: // ( float )			==		( string )
     case VARIABLE_CHAR
-        + VARIABLE_STRING *VARIABLE_MAX: // ( char )				==		( string )
-    case VARIABLE_CONSTSTRING
-        + VARIABLE_STRING *VARIABLE_MAX: // ( const string )		==		( string )
+        + VARIABLE_STRING                       *VARIABLE_MAX: // ( char )				==		( string )
+    case VARIABLE_CONSTSTRING + VARIABLE_STRING *VARIABLE_MAX: // ( const string )		==		( string )
     case VARIABLE_LISTENER
         + VARIABLE_STRING                  *VARIABLE_MAX: // ( listener )			==		( string )
     case VARIABLE_VECTOR + VARIABLE_STRING *VARIABLE_MAX: // ( vector )			==		( string )
@@ -2031,10 +2054,9 @@ bool ScriptVariable::operator==(const ScriptVariable& value)
     case VARIABLE_CONSTSTRING + VARIABLE_CHAR    *VARIABLE_MAX: // ( const string )		==		( char )
     case VARIABLE_STRING + VARIABLE_LISTENER     *VARIABLE_MAX: // ( string )			==		( listener )
     case VARIABLE_CONSTSTRING
-        + VARIABLE_LISTENER                *VARIABLE_MAX: // ( const string )		==		( listener )
-    case VARIABLE_STRING + VARIABLE_VECTOR *VARIABLE_MAX: // ( string )			==		( vector )
-    case VARIABLE_CONSTSTRING
-        + VARIABLE_VECTOR *VARIABLE_MAX: // ( const string )		==		( vector )
+        + VARIABLE_LISTENER                     *VARIABLE_MAX: // ( const string )		==		( listener )
+    case VARIABLE_STRING + VARIABLE_VECTOR      *VARIABLE_MAX: // ( string )			==		( vector )
+    case VARIABLE_CONSTSTRING + VARIABLE_VECTOR *VARIABLE_MAX: // ( const string )		==		( vector )
         {
             str lval = stringValue();
             str rval = value.stringValue();
@@ -2046,7 +2068,7 @@ bool ScriptVariable::operator==(const ScriptVariable& value)
         return m_data.charValue == value.m_data.charValue;
 
     case VARIABLE_VECTOR + VARIABLE_VECTOR *VARIABLE_MAX: // ( vector ) == ( vector )
-        return VectorCompare(m_data.vectorValue, value.m_data.vectorValue) ? true : false;
+        return VectorCompareEpsilon(m_data.vectorValue, value.m_data.vectorValue, 0.0001) ? true : false;
     }
 }
 
@@ -2250,10 +2272,7 @@ void ScriptVariable::complement(void)
     if (type == VARIABLE_INTEGER) {
         m_data.intValue = ~m_data.intValue;
     } else {
-        float value = floatValue();
-        int   i     = ~*(int *)&value; // ley0k: evil floating point hack
-
-        setFloatValue(*(float *)&i);
+        setIntValue(~intValue());
     }
 }
 
@@ -2278,17 +2297,17 @@ void ScriptVariable::greaterthan(ScriptVariable& variable)
         break;
 
     case VARIABLE_INTEGER + VARIABLE_FLOAT *VARIABLE_MAX: // ( int ) > ( float )
-        m_data.intValue = m_data.intValue > variable.m_data.floatValue;
+        m_data.intValue = m_data.intValue - variable.m_data.floatValue >= 0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_FLOAT *VARIABLE_MAX: // ( float ) > ( float )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue > variable.m_data.floatValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.floatValue >= 0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_INTEGER *VARIABLE_MAX: // ( float ) > ( int )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue > variable.m_data.intValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.intValue >= 0.0001;
         break;
 
     case VARIABLE_CHAR + VARIABLE_CHAR *VARIABLE_MAX: // ( char ) > ( char )
@@ -2319,17 +2338,17 @@ void ScriptVariable::greaterthanorequal(ScriptVariable& variable)
         break;
 
     case VARIABLE_INTEGER + VARIABLE_FLOAT *VARIABLE_MAX: // ( int ) >= ( float )
-        m_data.intValue = m_data.intValue >= variable.m_data.floatValue;
+        m_data.intValue = m_data.intValue - variable.m_data.floatValue > -0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_FLOAT *VARIABLE_MAX: // ( float ) >= ( float )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue >= variable.m_data.floatValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.floatValue > -0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_INTEGER *VARIABLE_MAX: // ( float ) >= ( int )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue >= variable.m_data.intValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.intValue > -0.0001;
         break;
 
     case VARIABLE_CHAR + VARIABLE_CHAR *VARIABLE_MAX: // ( char ) >= ( char )
@@ -2360,17 +2379,17 @@ void ScriptVariable::lessthan(ScriptVariable& variable)
         break;
 
     case VARIABLE_INTEGER + VARIABLE_FLOAT *VARIABLE_MAX: // ( int ) < ( float )
-        m_data.intValue = m_data.intValue < variable.m_data.floatValue;
+        m_data.intValue = m_data.intValue - variable.m_data.floatValue <= -0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_FLOAT *VARIABLE_MAX: // ( float ) < ( float )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue < variable.m_data.floatValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.floatValue <= -0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_INTEGER *VARIABLE_MAX: // ( float ) < ( int )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue < variable.m_data.intValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.intValue <= -0.0001;
         break;
 
     case VARIABLE_CHAR + VARIABLE_CHAR *VARIABLE_MAX: // ( char ) < ( char )
@@ -2401,17 +2420,17 @@ void ScriptVariable::lessthanorequal(ScriptVariable& variable)
         break;
 
     case VARIABLE_INTEGER + VARIABLE_FLOAT *VARIABLE_MAX: // ( int ) <= ( float )
-        m_data.intValue = m_data.intValue <= variable.m_data.floatValue;
+        m_data.intValue = m_data.intValue - variable.m_data.floatValue < 0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_FLOAT *VARIABLE_MAX: // ( float ) <= ( float )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue <= variable.m_data.floatValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.floatValue < 0.0001;
         break;
 
     case VARIABLE_FLOAT + VARIABLE_INTEGER *VARIABLE_MAX: // ( float ) <= ( int )
         type            = VARIABLE_INTEGER;
-        m_data.intValue = m_data.floatValue <= variable.m_data.intValue;
+        m_data.intValue = m_data.floatValue - variable.m_data.intValue < 0.0001;
         break;
 
     case VARIABLE_CHAR + VARIABLE_CHAR *VARIABLE_MAX: // ( char ) <= ( char )
@@ -2617,6 +2636,11 @@ ScriptVariable *ScriptVariableList::SetVariable(unsigned int name, ScriptVariabl
     return variable;
 }
 
+int ScriptVariableList::size() const
+{
+    return list.size();
+}
+
 void ScriptVariableList::Archive(Archiver& arc)
 {
     Class::Archive(arc);
@@ -2632,6 +2656,17 @@ void ScriptVariableList::MakePrimitive()
     }
 }
 
+void ScriptVariableList::Print(void (*PrintFn)(const char *format, ...))
+{
+    con_set_enum<short3, ScriptVariable> en = list;
+
+    for (con_set_enum<short3, ScriptVariable>::Entry *entry = en.NextElement(); entry; entry = en.NextElement()) {
+        (*PrintFn)("%s = %s\n", entry->value.getName().c_str(), entry->value.stringValue().c_str());
+    }
+
+    gi.Printf("%d variables\n", list.size());
+}
+
 CLASS_DECLARATION(Class, ScriptVariableList, NULL) {
     {NULL, NULL}
 };
