@@ -246,8 +246,8 @@ void ScriptVMStack::Archive(Archiver& arc)
     unsigned int i;
 
     if (arc.Saving()) {
-        size   = stackBottom - localStack;
-        offset = pTop - localStack;
+        size    = stackBottom - localStack;
+        offset  = pTop - localStack;
         numVars = offset + 1;
 
         arc.ArchiveUnsigned(&size);
@@ -312,7 +312,7 @@ ScriptVM::ScriptVM()
     m_pOldData    = NULL;
     m_OldDataSize = 0;
 
-    m_StackPos   = NULL;
+    m_StackPos = NULL;
 }
 
 /*
@@ -339,7 +339,7 @@ ScriptVM::ScriptVM(ScriptClass *scriptClass, unsigned char *pCodePos, ScriptThre
     m_pOldData    = NULL;
     m_OldDataSize = 0;
 
-    m_StackPos   = NULL;
+    m_StackPos = NULL;
 
     m_ScriptClass->AddThread(this);
 
@@ -541,6 +541,8 @@ void ScriptVM::executeCommandInternal<false>(
 )
 {
     transferVarsToEvent(ev, fromVar, iParamCount);
+
+    checkValidEvent(ev, listener);
     listener->ProcessScriptEvent(ev);
 }
 
@@ -552,6 +554,7 @@ void ScriptVM::executeCommandInternal<true>(
     transferVarsToEvent(ev, fromVar, iParamCount);
 
     try {
+        checkValidEvent(ev, listener);
         listener->ProcessScriptEvent(ev);
     } catch (...) {
         m_VMStack.GetTop().Clear();
@@ -595,6 +598,26 @@ void ScriptVM::transferVarsToEvent(Event& ev, ScriptVariable *fromVar, op_parmNu
     ev.CopyValues(fromVar, count);
 }
 
+void ScriptVM::checkValidEvent(Event& ev, Listener *listener)
+{
+    ClassDef *c = listener->classinfo();
+
+    if (!c->GetDef(&ev)) {
+        if (listener == m_Thread) {
+            ScriptError("Failed execution of command '%s'", ev.getName());
+        } else if (listener->isSubclassOf(SimpleEntity)) {
+            ScriptError(
+                "Failed execution of command '%s' for class '%s' Targetname '%s'",
+                ev.getName(),
+                c->classname,
+                static_cast<SimpleEntity *>(listener)->targetname.c_str()
+            );
+        } else {
+            ScriptError("Failed execution of command '%s' for class '%s'", ev.getName(), c->classname);
+        }
+    }
+}
+
 bool ScriptVM::executeGetter(Listener *listener, op_evName_t eventName)
 {
     int eventNum = Event::FindGetterEventNum(eventName);
@@ -1517,6 +1540,7 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
 
             case OP_LOAD_STORE_SELF_VAR:
                 if (!m_ScriptClass->m_Self) {
+                    m_CodePos += sizeof(unsigned int);
                     ScriptError("self is NULL");
                 }
 
@@ -1524,7 +1548,7 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
                 break;
 
             case OP_MARK_STACK_POS:
-                m_StackPos   = &m_VMStack.GetTop();
+                m_StackPos             = &m_VMStack.GetTop();
                 m_VMStack.m_bMarkStack = true;
                 break;
 
@@ -1648,13 +1672,13 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
 
             case OP_STORE_OWNER_VAR:
                 if (!m_ScriptClass->m_Self) {
-                    m_VMStack.Push();
+                    m_VMStack.PushAndGet().Clear();
                     m_CodePos += sizeof(unsigned int);
                     ScriptError("self is NULL");
                 }
 
                 if (!m_ScriptClass->m_Self->GetScriptOwner()) {
-                    m_VMStack.Push();
+                    m_VMStack.PushAndGet().Clear();
                     m_CodePos += sizeof(unsigned int);
                     ScriptError("self.owner is NULL");
                 }
@@ -1668,7 +1692,7 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
 
             case OP_STORE_SELF_VAR:
                 if (!m_ScriptClass->m_Self) {
-                    m_VMStack.Push();
+                    m_VMStack.PushAndGet().Clear();
                     m_CodePos += sizeof(unsigned int);
                     ScriptError("self is NULL");
                 }
@@ -1697,10 +1721,10 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
                 break;
 
             case OP_STORE_OWNER:
-                m_VMStack.Push();
-
-                if (!m_ScriptClass->m_Self) {
+                if (m_ScriptClass->m_Self) {
                     m_VMStack.Push();
+                } else {
+                    m_VMStack.PushAndGet().Clear();
                     ScriptError("self is NULL");
                 }
 
@@ -1769,7 +1793,13 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
 
             case OP_UN_TARGETNAME:
                 // retrieve the target name
-                targetList = world->GetExistingTargetList(m_VMStack.GetTop().stringValue());
+                if (world) {
+                    targetList = world->GetExistingTargetList(m_VMStack.GetTop().stringValue());
+                } else {
+                    // Added in OPM
+                    //  don't use the target list if the world is NULL
+                    targetList = NULL;
+                }
 
                 if (!targetList || !targetList->list.NumObjects()) {
                     str targetname = m_VMStack.GetTop().stringValue();
@@ -1814,7 +1844,7 @@ void ScriptVM::Execute(ScriptVariable *data, int dataSize, str label)
 
             if (Director.cmdCount >= 15000) {
                 if (!Director.cmdTime) {
-                    Director.cmdTime = gi.Milliseconds();
+                    Director.cmdTime  = gi.Milliseconds();
                     Director.cmdCount = 0;
                     continue;
                 }
