@@ -326,14 +326,15 @@ typedef struct {
 } serverStatic_t;
 
 #define SERVER_MAXBANS	1024
+#define MAX_REASON_LENGTH 128
+
 // Structure for managing bans
-typedef struct
-{
+typedef struct serverBan_s {
 	netadr_t ip;
 	// For a CIDR-Notation type suffix
 	int subnet;
-	
 	qboolean isexception;
+	char reason[MAX_REASON_LENGTH];
 } serverBan_t;
 
 //=============================================================================
@@ -388,6 +389,8 @@ extern	cvar_t	*sv_strictAuth;
 #endif
 extern	cvar_t	*sv_banFile;
 
+extern  cvar_t  *sv_logContext;
+
 extern	serverBan_t serverBans[SERVER_MAXBANS];
 extern	int serverBansCount;
 
@@ -436,6 +439,8 @@ void SV_MasterHeartbeat (void);
 void SV_MasterShutdown (void);
 int SV_RateMsec(client_t *client);
 
+void SV_PrintfClient(int clientNum, const char *fmt, ...);
+
 void SV_ArchiveHudDrawElements( qboolean loading );
 void SV_HudDrawShader( int iInfo, const char *name );
 void SV_HudDrawAlign( int iInfo, int iHorizontalAlign, int iVerticalAlign );
@@ -489,6 +494,8 @@ void SV_SpawnServer( const char *server, qboolean loadgame, qboolean restart, qb
 int SV_PVSSoundIndex(const char* name, qboolean streamed);
 void SV_HandleNonPVSSound();
 
+void SV_ApplyOriginalConfigTweaks();
+
 
 //
 // sv_client.c
@@ -630,14 +637,6 @@ void SV_NET_UpdateClientNetProfileInfo(netprofclient_t* netprofile, int rate);
 void SV_NET_UpdateAllNetProfileInfo();
 void SV_NET_CalcTotalNetProfile(netprofclient_t* netprofile, qboolean server);
 
-//
-// sv_gamespy.c
-//
-void SV_GamespyHeartbeat();
-void SV_ProcessGamespyQueries();
-qboolean SV_InitGamespy();
-void SV_ShutdownGamespy();
-
 #ifdef __cplusplus
 }
 #endif
