@@ -196,18 +196,23 @@ void SV_AuthorizeIpPacket( netadr_t from ) {
 SV_IsBanned
 
 Check whether a certain address is banned
+Returns the reason string if available
 ==================
 */
 
-static qboolean SV_IsBanned(netadr_t *from, qboolean isexception)
+static qboolean SV_IsBanned(netadr_t *from, qboolean isexception, char *reason, int reason_size)
 {
 	int index;
 	serverBan_t *curban;
 	
+	if(reason && reason_size > 0) {
+		reason[0] = '\0';
+	}
+	
 	if(!isexception)
 	{
 		// If this is a query for a ban, first check whether the client is excepted
-		if(SV_IsBanned(from, qtrue))
+		if(SV_IsBanned(from, qtrue, NULL, 0))
 			return qfalse;
 	}
 	
@@ -217,8 +222,13 @@ static qboolean SV_IsBanned(netadr_t *from, qboolean isexception)
 		
 		if(curban->isexception == isexception)
 		{
-			if(NET_CompareBaseAdrMask(curban->ip, *from, curban->subnet))
+			if(NET_CompareBaseAdrMask(curban->ip, *from, curban->subnet)) {
+				// Copy the ban reason if available and a buffer was provided
+				if(reason && reason_size > 0 && curban->reason[0]) {
+					Q_strncpyz(reason, curban->reason, reason_size);
+				}
 				return qtrue;
+			}
 		}
 	}
 	
@@ -233,21 +243,34 @@ Find or create challenge, from the specified ip address
 ==================
 */
 challenge_t* FindChallenge(netadr_t from, qboolean connecting) {
-	int		i;
-	int		oldest;
-	int		oldestTime;
-	challenge_t	*challenge;
+	int		    i;
+	int		    oldest;
+	int		    oldestTime;
+	int		    oldestClientTime;
+	qboolean    wasfound = qfalse;
+	challenge_t *challenge;
 
 	oldest = 0;
-	oldestTime = 0x7fffffff;
+	oldestClientTime = oldestTime = 0x7fffffff;
 
 	// see if we already have a challenge for this ip
 	challenge = &svs.challenges[0];
 	if (connecting) {
 		for (i = 0; i < MAX_CHALLENGES; i++, challenge++) {
-			if (!challenge->connected && NET_CompareAdr(from, challenge->adr)) {
-				break;
-			}
+            if(!challenge->connected && NET_CompareAdr(from, challenge->adr))
+            {
+                wasfound = qtrue;
+                
+                if(challenge->time < oldestClientTime)
+                    oldestClientTime = challenge->time;
+            }
+
+            if(wasfound && i >= MAX_CHALLENGES_MULTI)
+            {
+                i = MAX_CHALLENGES;
+                break;
+            }
+
 			if (challenge->time < oldestTime) {
 				oldestTime = challenge->time;
 				oldest = i;
@@ -269,7 +292,6 @@ challenge_t* FindChallenge(netadr_t from, qboolean connecting) {
 		// this is the first time this client has asked for a challenge
 		challenge = &svs.challenges[oldest];
 
-		challenge->challenge = ( (rand() << 16) ^ rand() ) ^ svs.time;
 		challenge->adr = from;
 		challenge->firstTime = svs.time;
 		challenge->time = svs.time;
@@ -281,6 +303,11 @@ challenge_t* FindChallenge(netadr_t from, qboolean connecting) {
 		SV_CreateGamespyChallenge(challenge->gsChallenge);
 	}
 
+	// always generate a new challenge number, so the client cannot circumvent sv_maxping
+	challenge->challenge = ( (rand() << 16) ^ rand() ) ^ svs.time;
+	challenge->wasrefused = qfalse;
+	challenge->time = svs.time;
+
 	return challenge;
 }
 
@@ -333,17 +360,23 @@ void SV_DirectConnect( netadr_t from ) {
 	qboolean	compat = qfalse;
 #endif
 	challenge_t* ch;
-
-	Com_DPrintf ("SVC_DirectConnect ()\n");
-	
-	// Check whether this client is banned.
-	if(SV_IsBanned(&from, qfalse))
-	{
-		SV_NET_OutOfBandPrint( &svs.netprofile, from, "droperror\nYou are banned from this server.\n");
-		return;
-	}
+	char        banReason[MAX_REASON_LENGTH];
 
 	Q_strncpyz( userinfo, Cmd_Argv(1), sizeof(userinfo) );
+	Com_DPrintf ("SVC_DirectConnect ()\n>>>%s<<<\n", userinfo);
+	
+	// Check whether this client is banned.
+	if(SV_IsBanned(&from, qfalse, banReason, sizeof(banReason)))
+	{
+		if(banReason[0]) {
+			SV_NET_OutOfBandPrint( &svs.netprofile, from, "droperror\nYou are banned from this server.\nReason: %s\n", banReason);
+            Com_DPrintf("    rejected connect due to banned IP for reason: %s\n", banReason);
+		} else {
+			SV_NET_OutOfBandPrint( &svs.netprofile, from, "droperror\nYou are banned from this server.\n");
+            Com_DPrintf("    rejected connect due to banned IP (reason unspecified)\n");
+		}
+		return;
+	}
 
 	if (com_target_game->integer >= TG_MOHTT) {
 		const char* clientType;
@@ -415,6 +448,7 @@ void SV_DirectConnect( netadr_t from ) {
 		SV_NET_OutOfBandPrint( &svs.netprofile, from,
 			"droperror\nUserinfo string length exceeded.  "
 			"Try removing setu cvars from your config.\n" );
+        Com_DPrintf("%s:rejected, userinfo string length exceeded\n", ip);
 		return;
 	}
 	Info_SetValueForKey( userinfo, "ip", ip );
@@ -586,6 +620,10 @@ gotnewcl:
 		return;
 	}
 
+    // Added in OPM
+    //  Show the IP address of the client that is connecting
+    Com_Printf("Client %i (IP: %s) is connecting\n", clientNum, ip);
+
 	ch = FindChallenge(from, qfalse);
 	if (ch) {
 		newcl->gamespyId = ch->gamespyId;
@@ -1461,10 +1499,26 @@ void SV_UserinfoChanged( client_t *cl ) {
 	char	*ip;
 	int		i;
 	int	len;
+	char oldname[MAX_NAME_LENGTH];
+
+    // Added in OPM
+	Q_strncpyz( oldname, cl->name, sizeof(oldname) );
 
 	// name for C code
 	Q_strncpyz( cl->name, Info_ValueForKey (cl->userinfo, "name"), sizeof(cl->name) );
 
+    //
+    // Added in OPM
+    //  Print name changes
+    //
+    if (cl->state != CS_FREE) {
+        if (!oldname[0]) {
+            SV_PrintfClient(cl - svs.clients, "is using this name\n");
+        } else if (strcmp(oldname, cl->name)) {
+            SV_PrintfClient(cl - svs.clients, "has changed name (old name was '%s')\n", oldname);
+        }
+    }
+
 	// rate command
 
 	// if the client is on the same subnet as the server and we aren't running an
