@@ -1264,12 +1264,14 @@ qboolean PF_setmodel( gentity_t *ent, const char *name )
 
 		// don't reference the model again
 		if( ent->s.modelindex == newModelIndex ) {
+            assert(modelUserCount[ ent->s.modelindex ] > 0);
 			return qtrue;
 		}
 	}
 
 	if( ent->tiki && ent->s.modelindex )
 	{
+        assert(modelUserCount[ ent->s.modelindex ] > 0);
 		modelUserCount[ ent->s.modelindex ]--;
 		if( !modelUserCount[ ent->s.modelindex ] )
 			SV_ClearModel( ent->s.modelindex );
@@ -1772,6 +1774,7 @@ void SV_InitGameProgs( void ) {
 	import.cvar_set						= Cvar_Set;
 	import.cvar_set2					= Cvar_Set2;
 	import.NextCvar						= Cvar_Next;
+	import.Cvar_CheckRange				= Cvar_CheckRange;
 
 	import.Argc							= Cmd_Argc;
 	import.Args							= Cmd_Args;
@@ -1786,6 +1789,7 @@ void SV_InitGameProgs( void ) {
 	import.FS_WriteFile					= FS_WriteFile;
 	import.FS_FOpenFileWrite			= FS_FOpenFileWrite;
 	import.FS_FOpenFileAppend			= FS_FOpenFileAppend;
+	import.FS_FOpenFile					= FS_FOpenFileRead;
 	import.FS_PrepFileWrite				= FS_PrepFileWrite;
 	import.FS_Write						= FS_Write;
 	import.FS_Read						= FS_Read;
@@ -1908,6 +1912,7 @@ void SV_InitGameProgs( void ) {
 	import.fsDebug						= fs_debug;
 
 	// Added in OPM
+    import.PrintfClient                 = SV_PrintfClient;
 	import.pvssoundindex				= SV_PVSSoundIndex;
 
 	ge = Sys_GetGameAPI( &import );
