@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "../client/client.h"
 #include "../qcommon/tiki.h"
 #include "../qcommon/bg_compat.h"
+#include "../gamespy/sv_gamespy.h"
 
 static char last_mapname[ MAX_QPATH ];
 static int g_iSvsTimeFixupCount;
@@ -146,6 +147,7 @@ SV_FindIndex
 */
 int SV_FindIndex( const char *name, int start, int max, qboolean create ) {
 	int		i;
+	int		result;
 	char	*s;
 
 	if( !name || !name[ 0 ] ) {
@@ -163,10 +165,21 @@ int SV_FindIndex( const char *name, int start, int max, qboolean create ) {
 	for( i = 1; i<max; i++ ) {
 		s = sv.configstrings[ start + i ];
 
-		if( !s || !s[ 0 ] ) {
+		if( !s[0] ) {
 			break;
 		}
-		if( !strcmp( s, name ) ) {
+
+		if( !Q_stricmp( s, name ) ) {
+			return i;
+		}
+	}
+
+    result = i;
+
+	for( i = result; i<max; i++ ) {
+		s = sv.configstrings[ start + i ];
+
+		if( !Q_stricmp( s, name ) ) {
 			return i;
 		}
 	}
@@ -175,12 +188,12 @@ int SV_FindIndex( const char *name, int start, int max, qboolean create ) {
 		return 0;
 	}
 
-	if( i == max ) {
+	if( result == max ) {
 		Com_Error( 1, "SV_FindIndex: overflow  max%d create%d  name %s", max, create, name );
 	}
 
-	SV_SetConfigstring( start + i, name );
-	return i;
+	SV_SetConfigstring( start + result, name );
+	return result;
 }
 
 /*
@@ -1100,15 +1113,28 @@ void SV_Init (void)
 #endif
 	sv_banFile = Cvar_Get("sv_banFile", "serverbans.dat", CVAR_ARCHIVE);
 
+    // Added in OPM
+    sv_logContext = Cvar_Get("sv_logContext", "1", 0);
+
 	Q_strncpyz( svs.gameName, "current", sizeof(svs.gameName) );
 
 	// dday vars
-	Cvar_Get( "g_ddayfodderguys", "0", CVAR_ARCHIVE );
-	Cvar_Get( "g_ddayfog", "2", CVAR_ARCHIVE );
-	Cvar_Get( "g_ddayshingleguys", "0", CVAR_ARCHIVE );
+
+	// Changed in OPM
+	//  Use a more distant fog by default on dday.
+	//  A thicker fog causes the sky to disappear at some location.
+	Cvar_Get( "g_ddayfodderguys", "2", CVAR_ARCHIVE );
+	Cvar_Get( "g_ddayfog", "0", CVAR_ARCHIVE );
+	Cvar_Get( "g_ddayshingleguys", "2", CVAR_ARCHIVE );
 	
 	// Load saved bans
 	Cbuf_AddText("rehashbans\n");
+
+    if (com_gotOriginalConfig) {
+        // Added in OPM
+        //  Apply config tweaks after loading the original config
+		SV_ApplyOriginalConfigTweaks();
+	}
 }
 
 
@@ -1325,3 +1351,11 @@ void SV_HandleNonPVSSound()
 	SV_CleanupNonPVSSound();
 }
 
+/*
+===============
+SV_ApplyOriginalConfigTweaks
+===============
+*/
+void SV_ApplyOriginalConfigTweaks()
+{
+}
