@@ -80,6 +80,8 @@ cvar_t	*sv_strictAuth;
 #endif
 cvar_t	*sv_banFile;
 
+cvar_t  *sv_logContext;
+
 serverBan_t serverBans[SERVER_MAXBANS];
 int serverBansCount = 0;
 
@@ -158,10 +160,25 @@ not have future snapshot_t executed before it is executed
 void SV_AddServerCommand( client_t *client, const char *cmd ) {
 	int		index, i;
 
-	// this is very ugly but it's also a waste to for instance send multiple config string updates
-	// for the same config string index in one snapshot
-	if ( !strncmp(cmd, "cs ", 3) && SV_ReplacePendingServerCommands(client, cmd) ) {
-		return;
+	if ( com_protocol->integer >= PROTOCOL_MOHTA_MIN ) {
+		// Added in 2.0
+		//  Requires spearhead clients.
+		//  Unfortunately in MOHAA 1.11, replacing cs can cause clients to crash
+		//  when an existing model is moved into a lower configstring.
+		//  For example:
+		//   cs 138 models/weapons/mp40.tik
+		//   cs 117 models/weapons/m1_garand.tik
+		//   1) models/weapons/mp40.tik is already referenced by cs 117, it will cause the model handle to be referenced twice.
+		//   2) when the client executes "cs 117", it will free up the mp40.tik model, leaving a dangling handle for cs 138.
+
+		// FIXME: To make it work on MOHAA clients, reorder configstrings that are sent to clients.
+		// For example, always put "cs 117" before "cs 138".
+
+		// this is very ugly but it's also a waste to for instance send multiple config string updates
+		// for the same config string index in one snapshot
+		if ( !strncmp( cmd, "cs ", 3 ) && SV_ReplacePendingServerCommands( client, cmd ) ) {
+			return;
+		}
 	}
 
 	// do not send commands until the gamestate has been sent
@@ -267,7 +284,7 @@ void SV_MasterHeartbeat( void ) {
 
 	if (svs.time >= svs.nextHeartbeatTime)
 	{
-		svs.nextHeartbeatTime = svs.time + MAX_HEARTBEAT_TIME;
+		svs.nextHeartbeatTime = svs.time + HB_TIME;
 		SV_GamespyHeartbeat();
 	}
 }
@@ -624,9 +641,9 @@ void SVC_Info( netadr_t from ) {
 	}
 
     if (!com_target_demo->integer || com_target_game->integer <= TG_MOH) {
-        Info_SetValueForKey(infostring, "gamever", com_target_version->string);
+        Info_SetValueForKey(infostring, "gamever", com_target_shortversion->string);
 	} else {
-		Info_SetValueForKey(infostring, "gamever", va("d%s", com_target_version->string));
+		Info_SetValueForKey(infostring, "gamever", va("d%s", com_target_shortversion->string));
 	}
 
 	if (com_target_game->integer >= TG_MOHTT) {
@@ -660,7 +677,7 @@ static void SVC_RemoteCommand( netadr_t from, msg_t *msg ) {
 	char		remaining[1024];
 	// TTimo - scaled down to accumulate, but not overflow anything network wise, print wise etc.
 	// (OOB messages are the bottleneck here)
-#define SV_OUTPUTBUF_LENGTH (1024 - 16)
+#define SV_OUTPUTBUF_LENGTH (8192 - 16)
 	char		sv_outputbuf[SV_OUTPUTBUF_LENGTH];
 	char *cmd_aux;
 
@@ -1379,3 +1396,47 @@ int SV_SendQueuedPackets()
 
 	return timeVal;
 }
+
+/*
+=====================
+SV_PrintfClient
+=====================
+*/
+void SV_PrintfClient(int clientNum, const char *fmt, ...) {
+    client_t   *cl;
+    const char *addr, *name;
+    va_list     argptr;
+    char        msg[MAXPRINTMSG];
+
+    if (!com_dedicated->integer) {
+        // Only print client details on dedicated servers
+        return;
+    }
+
+    va_start(argptr, fmt);
+    Q_vsnprintf(msg, sizeof(msg), fmt, argptr);
+    va_end(argptr);
+
+    if (clientNum < 0 || clientNum >= svs.iNumClients) {
+        return;
+    }
+
+    cl = &svs.clients[clientNum];
+    if (cl->netchan.remoteAddress.type == NA_BAD) {
+        return;
+    }
+
+    name = cl->name;
+    if (!name[0]) {
+        name = Info_ValueForKey(cl->userinfo, "name");
+    }
+
+    if (!sv_logContext->integer) {
+        // Contextual print disabled
+        Com_Printf("%s %s", name, msg);
+        return;
+    }
+
+    addr = NET_AdrToStringwPort(cl->netchan.remoteAddress);
+    Com_Printf("{#%d | %s} %s %s", clientNum, addr, name, msg);
+}
