@@ -22,13 +22,26 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "../qcommon/q_version.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 // Setting DEFAULT_BASEDIR to an empty string will make
 // Sys_DefaultInstallPath() return the current directory instead
 // This was the usual behavior in Quake III Arena.
 #define DEFAULT_BASEDIR ""
 
 void Sys_InitEx();
+void Sys_ShutdownEx();
 
 void Sys_PrepareBackTrace();
 void Sys_PrintBackTrace();
-void Sys_PlatformInit_New();
\ No newline at end of file
+void Sys_PlatformInit_New();
+
+void Sys_UpdateChecker_Init();
+void Sys_UpdateChecker_Process();
+void Sys_UpdateChecker_Shutdown();
+
+#ifdef __cplusplus
+}
+#endif
\ No newline at end of file
