@@ -23,117 +23,117 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "ui_local.h"
 
 Event W_MouseExited
-	(
-	"mouse_exited",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Mouse exiting a widget event"
-	);
+(
+    "mouse_exited",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Mouse exiting a widget event"
+);
 Event W_MouseEntered
-	(
-	"mouse_entered",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Mouse Entered a widget event"
-	);
+(
+    "mouse_entered",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Mouse Entered a widget event"
+);
 Event W_LeftMouseDragged
-	(
-	"left_mousedragged",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Mouse was moved in a widget with the left button down"
-	);
+(
+    "left_mousedragged",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Mouse was moved in a widget with the left button down"
+);
 Event W_RightMouseDragged
-	(
-	"right_mousedragged",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Mouse was moved in a widget with the right button down"
-	);
+(
+    "right_mousedragged",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Mouse was moved in a widget with the right button down"
+);
 Event W_CenterMouseDragged
-	(
-	"center_mousedragged",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Mouse was moved in a widget with the center button down"
-	);
+(
+    "center_mousedragged",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Mouse was moved in a widget with the center button down"
+);
 Event W_MouseMoved
-	(
-	"mouse_moved",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Mouse was moved in a widget with no buttons down"
-	);
+(
+    "mouse_moved",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Mouse was moved in a widget with no buttons down"
+);
 Event W_LeftMouseDown
-	(
-	"left_mouse_down",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Left mouse button has been pressed down"
-	);
+(
+    "left_mouse_down",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Left mouse button has been pressed down"
+);
 Event W_LeftMouseUp
-	(
-	"left_mouse_up",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Left mouse button has been released"
-	);
+(
+    "left_mouse_up",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Left mouse button has been released"
+);
 Event W_RightMouseDown
-	(
-	"right_mouse_down",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Right mouse button has been pressed down"
-	);
+(
+    "right_mouse_down",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Right mouse button has been pressed down"
+);
 Event W_RightMouseUp
-	(
-	"right_mouse_up",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Right mouse button has been released"
-	);
+(
+    "right_mouse_up",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Right mouse button has been released"
+);
 Event W_CenterMouseDown
-	(
-	"center_mouse_down",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Center mouse button has been pressed down"
-	);
+(
+    "center_mouse_down",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Center mouse button has been pressed down"
+);
 Event W_CenterMouseUp
-	(
-	"center_mouse_up",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Center mouse button has been released"
-	);
+(
+    "center_mouse_up",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Center mouse button has been released"
+);
 Event W_AnyMouseDown
-	(
-	"any_mouse_down",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Any mouse button has been pressed"
-	);
+(
+    "any_mouse_down",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Any mouse button has been pressed"
+);
 Event W_AnyMouseUp
-	(
-	"any_mouse_up",
-	EV_DEFAULT,
-	"ffi",
-	"xpos ypos buttons",
-	"Any mouse button has been released"
-	);
+(
+    "any_mouse_up",
+    EV_DEFAULT,
+    "ffi",
+    "xpos ypos buttons",
+    "Any mouse button has been released"
+);
 
 UIWindowManager uWinMan;
 
@@ -199,8 +199,7 @@ UIWidget *UIWindowManager::getResponder(UIPoint2D& pos)
         //  Ignore the first responder if it's disabled
         //  this prevents the UI system from being blocked
         //  trying to activate the control
-        responder->CanActivate() && responder->isEnabled()
-        ) {
+        responder->CanActivate() && responder->isEnabled()) {
         return responder;
     }
 
@@ -258,11 +257,16 @@ void UIWindowManager::UpdateViews(void)
     if (m_cursor && m_showcursor && uid.uiHasMouse) {
         vec4_t col;
 
-        VectorSet4(col, 1, 1, 1, 1);
         set2D();
-        uii.Rend_SetColor(col);
 
-        uii.Rend_DrawPicStretched(uid.mouseX, uid.mouseY, 0, 0, 0, 0, 1, 1, m_cursor->GetMaterial());
+        // Added in OPM
+        //  Draw the mouse if it has been grabbed
+        if (IN_IsCursorActive()) {
+            VectorSet4(col, 1, 1, 1, 1);
+            uii.Rend_SetColor(col);
+
+            uii.Rend_DrawPicStretched(uid.mouseX, uid.mouseY, 0, 0, 0, 0, 1, 1, m_cursor->GetMaterial());
+        }
 
         m_font->setColor(UWhite);
 
@@ -346,7 +350,7 @@ void UIWindowManager::ServiceEvents(void)
 
     if (!m_cursor) {
         // initialize the cursor
-        setCursor("gfx/2d/mouse_cursor");
+        setCursor("gfx/2d/mouse_cursor.tga");
     }
 }
 
@@ -511,6 +515,9 @@ void UIWindowManager::setCursor(const char *string)
     } else {
         uii.Sys_Printf("Could not register shader '%s'\n", string);
     }
+
+    // Added in OPM
+    refreshCursor();
 }
 
 void UIWindowManager::showCursor(bool show)
@@ -559,7 +566,8 @@ qboolean UIWindowManager::KeyEvent(int key, unsigned int time)
     } else {
         if (m_bindactive) {
             m_bindactive->KeyEvent(key, time);
-        } else if (!(m_activeControl && m_activeControl->KeyEvent(key, time)) && (key == K_DOWNARROW || key == K_UPARROW)) {
+        } else if (!(m_activeControl && m_activeControl->KeyEvent(key, time))
+                   && (key == K_DOWNARROW || key == K_UPARROW)) {
             selwidget = m_activeControl;
             if (selwidget && selwidget != this) {
                 for (selwidget = m_activeControl; selwidget != NULL; selwidget = selwidget->getParent()) {
@@ -673,6 +681,8 @@ void UIWindowManager::RefreshShadersFromList(void)
         UIReggedMaterial *regged = m_materiallist.ObjectAt(i);
         regged->ReregisterMaterial();
     }
+
+    refreshCursor();
 }
 
 void UIWindowManager::DeactivateCurrentSmart(void)
@@ -691,7 +701,7 @@ void UIWindowManager::DeactivateCurrentSmart(void)
         if (!checking->getParent() || (checking->getParent() && checking->getParent()->IsDying())) {
             continue;
         }
-        
+
         for (sibling = checking->getPrevSibling(); sibling && !toset; sibling = sibling->getPrevSibling()) {
             if (sibling->CanActivate()) {
                 toset = sibling;
@@ -911,6 +921,7 @@ void UIWindowManager::Shutdown(void)
     }
 
     m_cursor = NULL;
+    IN_FreeCursor();
 
     UIWidget::Shutdown();
 }
@@ -963,3 +974,19 @@ void UIWindowManager::RemoveAllDialogBoxes(void)
         }
     }
 }
+
+void UIWindowManager::refreshCursor()
+{
+    byte *pic;
+    int   width, height;
+
+    // Added in OPM
+    //  Load cursor image and use it
+    if (!m_cursorname.length()) {
+        return;
+    }
+
+    if (uii.Rend_LoadRawImage(m_cursorname.c_str(), &pic, &width, &height)) {
+        IN_SetCursorFromImage(pic, width, height, uii.Rend_FreeRawImage);
+    }
+}
